# Disable debug information package creation
%define debug_package %{nil}

# Define the Go Import Path
%global goipath github.com/flightctl/flightctl

# SELinux specifics
%global selinuxtype targeted
%define selinux_policyver 3.14.3-67
%define agent_relabel_files() \
    semanage fcontext -a -t flightctl_agent_exec_t "/usr/bin/flightctl-agent" ; \
    restorecon -v /usr/bin/flightctl-agent

Name:           flightctl
Version:        0.7.0~main~47~g66773903
Release:        1.20250501214217480161.pr1125.47.g66773903%{?dist}
Summary:        Flight Control service

%gometa

License:        Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND ISC AND MIT
URL:            %{gourl}

Source0:        flightctl-0.7.0~main~47~g66773903.tar.gz

BuildRequires:  golang
BuildRequires:  make
BuildRequires:  git
BuildRequires:  openssl-devel

Requires: openssl

# Skip description for the main package since it won't be created
%description
# Main package is empty and not created.

# cli sub-package
%package cli
Summary: Flight Control CLI
%description cli
flightctl is the CLI for controlling the Flight Control service.

# agent sub-package
%package agent
Summary: Flight Control management agent

Requires: flightctl-selinux = %{version}
Requires: bootc

%description agent
The flightctl-agent package provides the management agent for the Flight Control fleet management service.

# selinux sub-package
%package selinux
Summary: SELinux policies for the Flight Control management agent
BuildRequires: selinux-policy >= %{selinux_policyver}
BuildRequires: selinux-policy-devel >= %{selinux_policyver}
BuildArch: noarch
Requires: selinux-policy >= %{selinux_policyver}

%description selinux
The flightctl-selinux package provides the SELinux policy modules required by the Flight Control management agent.

# services sub-package
%package services
Summary: Flight Control services
Requires: bash
Requires: podman

%description services
The flightctl-services package provides installation and setup of files for running containerized Flight Control services

%prep
%goprep -A
%setup -q %{forgesetupargs} -n flightctl-0.7.0~main~47~g66773903

%build
    # if this is a buggy version of go we need to set GOPROXY as workaround
    # see https://github.com/golang/go/issues/61928
    GOENVFILE=$(go env GOROOT)/go.env
    if [[ ! -f "${GOENVFILE}" ]]; then
        export GOPROXY='https://proxy.golang.org,direct'
    fi

    SOURCE_GIT_TAG=$(echo %{version} | tr '~' '-') \
    SOURCE_GIT_TREE_STATE=clean \
    SOURCE_GIT_COMMIT=$(echo %{version} | awk -F'[-~]g' '{print $2}') \
    SOURCE_GIT_TAG_NO_V=%{version} \
    make build-cli build-agent

    # SELinux modules build
    make --directory packaging/selinux

%install
    mkdir -p %{buildroot}/usr/bin
    mkdir -p %{buildroot}/etc/flightctl
    cp bin/flightctl %{buildroot}/usr/bin
    mkdir -p %{buildroot}/usr/lib/systemd/system
    mkdir -p %{buildroot}/%{_sharedstatedir}/flightctl
    mkdir -p %{buildroot}/usr/lib/flightctl/custom-info.d
    mkdir -p %{buildroot}/usr/lib/flightctl/hooks.d/{afterupdating,beforeupdating,afterrebooting,beforerebooting}
    mkdir -p %{buildroot}/usr/lib/greenboot/check/required.d
    install -m 0755 packaging/greenboot/flightctl-agent-running-check.sh %{buildroot}/usr/lib/greenboot/check/required.d/20_check_flightctl_agent.sh
    cp bin/flightctl-agent %{buildroot}/usr/bin
    cp packaging/must-gather/flightctl-must-gather %{buildroot}/usr/bin
    cp packaging/hooks.d/afterupdating/00-default.yaml %{buildroot}/usr/lib/flightctl/hooks.d/afterupdating
    cp packaging/systemd/flightctl-agent.service %{buildroot}/usr/lib/systemd/system
    bin/flightctl completion bash > flightctl-completion.bash
    install -Dpm 0644 flightctl-completion.bash -t %{buildroot}/%{_datadir}/bash-completion/completions
    bin/flightctl completion fish > flightctl-completion.fish
    install -Dpm 0644 flightctl-completion.fish -t %{buildroot}/%{_datadir}/fish/vendor_completions.d/
    bin/flightctl completion zsh > _flightctl-completion
    install -Dpm 0644 _flightctl-completion -t %{buildroot}/%{_datadir}/zsh/site-functions/
    install -d %{buildroot}%{_datadir}/selinux/packages/%{selinuxtype}
    install -m644 packaging/selinux/*.bz2 %{buildroot}%{_datadir}/selinux/packages/%{selinuxtype}

    rm -f licenses.list

    find . -type f -name LICENSE -or -name License | while read LICENSE_FILE; do
        echo "%{_datadir}/licenses/%{NAME}/${LICENSE_FILE}" >> licenses.list
    done
    mkdir -vp "%{buildroot}%{_datadir}/licenses/%{NAME}"
    cp LICENSE "%{buildroot}%{_datadir}/licenses/%{NAME}"

    mkdir -vp "%{buildroot}%{_docdir}/%{NAME}"

    for DOC in docs examples .markdownlint-cli2.yaml README.md; do
        cp -vr "${DOC}" "%{buildroot}%{_docdir}/%{NAME}/${DOC}"
    done

    # flightctl-services sub-package steps
    # Run the install script to move the quadlet files.
    #
    # The IMAGE_TAG is derived from the RPM version, which may include tildes (~)
    # for proper version sorting (e.g., 0.5.1~rc1-1). However, the tagged images
    # always use hyphens (-) instead of tildes (~). To ensure valid image tags we need
    # to transform the version string by replacing tildes with hyphens.
    CONFIG_READONLY_DIR="%{buildroot}%{_datadir}/flightctl" \
    CONFIG_WRITEABLE_DIR="%{buildroot}%{_sysconfdir}/flightctl" \
    QUADLET_FILES_OUTPUT_DIR="%{buildroot}%{_datadir}/containers/systemd" \
    SYSTEMD_UNIT_OUTPUT_DIR="%{buildroot}/usr/lib/systemd/system" \
    IMAGE_TAG=$(echo %{version} | tr '~' '-') \
    deploy/scripts/install.sh

    # Copy files needed for post install into the build root
    cp deploy/scripts/post_install.sh %{buildroot}%{_datadir}/flightctl/post_install.sh
    cp deploy/scripts/secrets.sh %{buildroot}%{_datadir}/flightctl/secrets.sh

    # Copy sos report flightctl plugin
    mkdir -p %{buildroot}/usr/share/sosreport
    cp packaging/sosreport/sos/report/plugins/flightctl.py %{buildroot}/usr/share/sosreport

%check
    %{buildroot}%{_bindir}/flightctl-agent version


%pre selinux
%selinux_relabel_pre -s %{selinuxtype}

%post selinux

%selinux_modules_install -s %{selinuxtype} %{_datadir}/selinux/packages/%{selinuxtype}/flightctl_agent.pp.bz2
%agent_relabel_files

%postun selinux

if [ $1 -eq 0 ]; then
    %selinux_modules_uninstall -s %{selinuxtype} flightctl_agent
fi

%posttrans selinux

%selinux_relabel_post -s %{selinuxtype}

%post services
%{_datadir}/flightctl/post_install.sh

# File listings
# No %files section for the main package, so it won't be built

%files cli -f licenses.list
    %{_bindir}/flightctl
    %license LICENSE
    %{_datadir}/bash-completion/completions/flightctl-completion.bash
    %{_datadir}/fish/vendor_completions.d/flightctl-completion.fish
    %{_datadir}/zsh/site-functions/_flightctl-completion

%files agent -f licenses.list
    %license LICENSE
    %dir /etc/flightctl
    %{_bindir}/flightctl-agent
    %{_bindir}/flightctl-must-gather
    /usr/lib/flightctl/hooks.d/afterupdating/00-default.yaml
    /usr/lib/systemd/system/flightctl-agent.service
    %{_sharedstatedir}/flightctl
    /usr/lib/greenboot/check/required.d/20_check_flightctl_agent.sh
    %{_docdir}/%{NAME}/*
    %{_docdir}/%{NAME}/.markdownlint-cli2.yaml
    /usr/share/sosreport/flightctl.py

%post agent
INSTALL_DIR="/usr/lib/python$(python3 --version | sed 's/^.* \(3[.][0-9]*\).*$/\1/')/site-packages/sos/report/plugins"
mkdir -p $INSTALL_DIR
cp /usr/share/sosreport/flightctl.py $INSTALL_DIR
chmod 0644 $INSTALL_DIR/flightctl.py
rm -rf /usr/share/sosreport


%files selinux
%{_datadir}/selinux/packages/%{selinuxtype}/flightctl_agent.pp.bz2

%files services
    %defattr(0644,root,root,-)
    # Files mounted to system config
    %dir %{_sysconfdir}/flightctl
    %dir %{_sysconfdir}/flightctl/pki
    %dir %{_sysconfdir}/flightctl/flightctl-api
    %dir %{_sysconfdir}/flightctl/flightctl-ui
    %dir %{_sysconfdir}/flightctl/flightctl-cli-artifacts
    %config(noreplace) %{_sysconfdir}/flightctl/service-config.yaml

    # Files mounted to data dir
    %dir %attr(0444,root,root) %{_datadir}/flightctl
    %dir %attr(0444,root,root) %{_datadir}/flightctl/flightctl-api
    %dir %attr(0444,root,root) %{_datadir}/flightctl/flightctl-db
    %dir %attr(0444,root,root) %{_datadir}/flightctl/flightctl-kv
    %dir %attr(0444,root,root) %{_datadir}/flightctl/flightctl-ui
    %dir %attr(0444,root,root) %{_datadir}/flightctl/flightctl-cli-artifacts
    %{_datadir}/flightctl/flightctl-api/config.yaml.template
    %{_datadir}/flightctl/flightctl-api/env.template
    %attr(0755,root,root) %{_datadir}/flightctl/flightctl-api/init.sh
    %attr(0755,root,root) %{_datadir}/flightctl/flightctl-api/create_aap_application.sh
    %attr(0755,root,root) %{_datadir}/flightctl/flightctl-db/enable-superuser.sh
    %{_datadir}/flightctl/flightctl-kv/redis.conf
    %{_datadir}/flightctl/flightctl-ui/env.template
    %attr(0755,root,root) %{_datadir}/flightctl/flightctl-ui/init.sh
    %attr(0755,root,root) %{_datadir}/flightctl/init_utils.sh
    %{_datadir}/flightctl/flightctl-cli-artifacts/env.template
    %{_datadir}/flightctl/flightctl-cli-artifacts/nginx.conf
    %attr(0755,root,root) %{_datadir}/flightctl/flightctl-cli-artifacts/init.sh
    %{_datadir}/containers/systemd/flightctl*

    # Handle permissions for scripts run as part of the rpm post install
    %attr(0755,root,root) %{_datadir}/flightctl/post_install.sh
    %attr(0755,root,root) %{_datadir}/flightctl/secrets.sh

    # Files mounted to lib dir
    /usr/lib/systemd/system/flightctl.target

%changelog

* Thu May 1 2025 Packit <hello@packit.dev> - 0.7.0~main~47~g66773903-1.20250501214217480161.pr1125.47.g66773903
- EDM-1016: Add experimental feature to register TPM collection functions (Lily Sturmann)
- EDM-1016: Add TPM client agent-side (Lily Sturmann)
- EDM-1016: Fix for TPM system path (Lily Sturmann)
- EDM-1500: Add localhost callback for cli login to created OAuth app, remove kv/db ports from container defs (Dakota Crowder)
- EDM-1016: Include collector function data in system info (Lily Sturmann)
- NO-ISSUE: Remove --previous from kubectl log collection (Avishay Traeger)
- EDM-1315: Add events to create/update/delete APIs (Avishay Traeger)
- EDM-1275: Event retention (Avishay Traeger)
- EDM-1276: Add event listing to CLI (Avishay Traeger)
- NO-ISSUE: Fix selector resolving (Avishay Traeger)
- EDM-1274: Store system events in the database (Avishay Traeger)
- EDM-1276: Implement API to retrieve events (Avishay Traeger)
- EDM-1337: Modify nginx config to use only tls 1.3 (Dakota Crowder)
- EDM-1337: Change Warning err messages to Error (Dakota Crowder)
- EDM-1337: Modify rpm spec for install (Dakota Crowder)
- EDM-1337: Adjust setup to use default user for cli container (Dakota Crowder)
- EDM-1337: Install a flightctl-cli-artifacts quadlet (Dakota Crowder)
- EDM-1061: Add function to get TPM vendor info (Lily Sturmann)
- EDM-1435: agent/systemInfo: refactor and implement api (Sam Batschelet)
- EDM-1436: api: extend systemInfo status (Sam Batschelet)
- EDM-837: Document builds with RHEL base image (Frank A. Zdarsky)
- NO-ISSUE: Wrong code is generated for python (Gregory Shilin)
- EDM-1016: Add TPM functionality and unit tests to support attestation (Lily Sturmann)
- NO-ISSUE: Fixing Lint (Siddarth R)
- NO-ISSUE: Add ARM support for CPUInfo (Siddarth R)
- EDM-1333: refactoring to tests (Eldar Weiss)
- EDM-1453: agent: improve transient error handling (Sam Batschelet)
- EDM-1428: Add reload support for configuration changes (Ori Amizur)
- EDM-1452: Fix reference to ensure websocket handler is configured with middleware (Dakota Crowder)
- JIRA-1450:Incorrect Endpoint Used for CSR Approval (Siddarth Royapally)

* Thu May 1 2025 Lily Sturmann <lkatalin@users.noreply.github.com> - 0.6.0~main~210~g967c8010-1.20250501171708368205.tpm.client.may.1.210.g967c8010
- dkejdesfe (Lily Sturmann)
- dkejdesfd (Lily Sturmann)
- dkejde (Lily Sturmann)
- dkeje (Lily Sturmann)
- abc (Lily Sturmann)
- aseklg (Lily Sturmann)
- aseklg (Lily Sturmann)
- aseklj (Lily Sturmann)
- asej (Lily Sturmann)
- 29slky (Lily Sturmann)
- 29slkj (Lily Sturmann)
- skj (Lily Sturmann)
- fooo (Lily Sturmann)
- foooo (Lily Sturmann)
- d (Lily Sturmann)
- c (Lily Sturmann)
- b (Lily Sturmann)
- a (Lily Sturmann)
- fooO (Lily Sturmann)
- fooo (Lily Sturmann)
- foo (Lily Sturmann)
- bug fix wip 2 (Lily Sturmann)
- bug fix wip (Lily Sturmann)
- fake commit for systemd change (Lily Sturmann)
- EDM-1016: Add experimental feature to register TPM collection functions (Lily Sturmann)
- EDM-1016: Add TPM client agent-side (Lily Sturmann)
- EDM-1016: Fix for TPM system path (Lily Sturmann)
- EDM-1016: Include collector function data in system info (Lily Sturmann)
- NO-ISSUE: Remove --previous from kubectl log collection (Avishay Traeger)
- EDM-1315: Add events to create/update/delete APIs (Avishay Traeger)
- EDM-1275: Event retention (Avishay Traeger)
- EDM-1276: Add event listing to CLI (Avishay Traeger)
- NO-ISSUE: Fix selector resolving (Avishay Traeger)
- EDM-1274: Store system events in the database (Avishay Traeger)
- EDM-1276: Implement API to retrieve events (Avishay Traeger)
- EDM-1337: Modify nginx config to use only tls 1.3 (Dakota Crowder)
- EDM-1337: Change Warning err messages to Error (Dakota Crowder)
- EDM-1337: Modify rpm spec for install (Dakota Crowder)
- EDM-1337: Adjust setup to use default user for cli container (Dakota Crowder)
- EDM-1337: Install a flightctl-cli-artifacts quadlet (Dakota Crowder)
- EDM-1061: Add function to get TPM vendor info (Lily Sturmann)
- EDM-1435: agent/systemInfo: refactor and implement api (Sam Batschelet)
- EDM-1436: api: extend systemInfo status (Sam Batschelet)
- EDM-837: Document builds with RHEL base image (Frank A. Zdarsky)
- NO-ISSUE: Wrong code is generated for python (Gregory Shilin)
- EDM-1016: Add TPM functionality and unit tests to support attestation (Lily Sturmann)
- NO-ISSUE: Fixing Lint (Siddarth R)
- NO-ISSUE: Add ARM support for CPUInfo (Siddarth R)
- EDM-1333: refactoring to tests (Eldar Weiss)
- EDM-1453: agent: improve transient error handling (Sam Batschelet)
- EDM-1428: Add reload support for configuration changes (Ori Amizur)
- EDM-1452: Fix reference to ensure websocket handler is configured with middleware (Dakota Crowder)
- JIRA-1450:Incorrect Endpoint Used for CSR Approval (Siddarth Royapally)
- EDM-1429: agent: react to changes (Sam Batschelet)
- EDM-1429: agent: add systeminfo manager (Sam Batschelet)
- EDM-1429: agent: add system-info subcommand (Sam Batschelet)
- NO-ISSUE: Use printf rather than echo -e (Dakota Crowder)
- NO-ISSUE: Fix newline run-on issue with no bootc agent container (Dakota Crowder)
- Revert "EDM-1374: Resource monitorType casing mismatch causes alert not being displayed" (Sam Batschelet)
- EDM-1184: changed SELinux policy to allow systemd to start the service (Mario Parra)
- EDM-1367: Create aap oauth app from auth token (Dakota Crowder)
- NO-ISSUE: gRPC streams connections are disconnected after 5 minutes (Ori Amizur)
- EDM-1414: Add patch support for DeviceStatus (Sam Batschelet)
- NO-ISSUE: Revert removal o tags by https://github.com/flightctl/flightctl/pull/1013/ (#1088) (Gregory Shilin)
- EDM-1413: Break out get_services_for_tag function (Dakota Crowder)
- EDM-1413: Address image ref diff for ui images in dev builds (Dakota Crowder)
- EDM-1413: Add comment for ~ replacement context (Dakota Crowder)
- EDM-1413: Set image tag for installed quadlets based off of rpm version (Dakota Crowder)
- EDM-1314: docs: add inline compose details (Sam Batschelet)
- EDM-1295: Configuration for cli artifacts in UI standalone deployment (Celia Amador)
- EDM-1370: Add comment to .target explaining what the Requires and After diretives mean wrt startup ordering (Dakota Crowder)
- EDM-1288: Create sos report plugin for flightctl (Ori Amizur)
- EDM-1370: Remove redundant Wants from target (Dakota Crowder)
- EDM-1370: Run daemon-reload in post install (Dakota Crowder)
- EDM-1370: Improve service dependency mappings and use a .target instead of slice (Dakota Crowder)
- EDM-1333: adding coverage for more steps (Eldar Weiss)
- EDM-1374: Resource monitorType casing mismatch causes alert not being displayed (Sam Batschelet)
- NO-ISSUE: agent/os: only pull if not booted (Sam Batschelet)
- NO-ISSUE: Cleanup remnants from grpc endpoint previously surfaced at 7444 (Dakota Crowder)
- EDM-1186: Updates to quadlets config and rpm spec per feedback (Dakota Crowder)
- EDM-1186: RPM Quadlet Installer initial implementation (Dakota Crowder)
- EDM-1186: Use podman secrets to manage db and kv passwords (Dakota Crowder)
- EDM-1394: Revert "EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update" (#1080) (Assaf Albo)
- NO-ISSUE: Fixed minor issues with helm chart when using gateway API (Ram)
- NO-ISSUE: fix for login validation (amalykhi)
- NO-ISSUE: flightctl login validation test (amalykhi)
- EDM-1305:  Console enhancements (Ori Amizur)
- EDM-1313: agent: ensure update error condition is visible (Sam Batschelet)
- EDM-996: flightctl-agent rpm should create /etc/flightctl/ directory (#1069) (Gregory Shilin)
- EDM-1318: Bug fix removing client cert creation at startup (noga-magen)
- EDM-1320: api: improve compose spec validations (Sam Batschelet)
- NO-ISSUE: agent: improve initial sync timing (Sam Batschelet)
- EDM-889: Separate out auth provider config (Frank A. Zdarsky)
- EDM-889: Revert change in token serialization (Frank A. Zdarsky)
- EDM-889: Omit empty fields (Frank A. Zdarsky)
- NO-ISSUE: Added Note (Siddarth R)
- NO-ISSUE: Define global pull policy and use IfNotPresent (rawagner)
- EDM-1320: applications: improve provider validation (Sam Batschelet)
- EDM-1049: Use Stringer to format version (Frank A. Zdarsky)
- EDM-1049: Show field names when printing JSON and YAML output (Frank A. Zdarsky)
- EDM-1049: Enable use of context global flag (Frank A. Zdarsky)
- EDM-1354: In OCP flightctl-cli-artifacts pod is in CrashLoopBackOff installing with the latest helm chart (rawagner)
- EDM-1352: Building a gitserver as a root user fails (#1058) (Gregory Shilin)
- EDM-1294: Expose CLI Downloads via route and gateway. Create ConsoleCLIDownloads CR. (rawagner)
- EDM-1293: Deploy a pod with CLI tools (#1036) (Gregory Shilin)
- EDM-1329: agent/resource: calculate CPU usage with delta-based sampling (Sam Batschelet)
- EDM-1254: Add user documentation for rollout policies (Ori Amizur)
- EDM-1346: bump x/oauth2 and x/crypto (rawagner)
- EDM-1165: Fix AuthZ middleware. Add tests (rawagner)
- EDM-851: Update DevicesSummary to prevent null return (Siddarth R)
- Revert "EDM 851: Update DevicesSummary OpenAPI spec" (Siddarth R)
- EDM-1317: EDM-1321: api: add missing inline application eval (Sam Batschelet)
- EDM-310: Refactor CA handling (Anton Ivanov)
- NO-ISSUE: Update helm charts with new UI params (rawagner)
- EDM 851: Update DevicesSummary OpenAPI spec (Siddarth R)
- NO-ISSUE: Fix status e2e test (sserafin)
- NO-ISSUE: Anchors are not currently supported for workflows (#1013) (Gregory Shilin)
- EDM-1308: Use chi middleware request IDs (Avishay Traeger)
- EDM-1211: *: implement inline application provider (Sam Batschelet)
- EDM-1211: agent/applications: refactor (Sam Batschelet)
- EDM-1211: api: add application inline provider (Sam Batschelet)
- EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update (#1011) (Assaf Albo)
- EDM-1309: Prevent client from setting ER status (Avishay Traeger)
- EDM-1252:Adding labels (Eldar101)
- EDM-696: Support AAP Gateway OAuth2 (rawagner)
- NO-ISSUE: Make example enrollment request valid (Celia Amador)
- EDM-1214: Perform better validation of CSR and enrollment requests (Anton Ivanov)
- EDM-1251: fix JSONB fields in CompositeSelectorResolver (#995) (Assaf Albo)
- EDM-1138: Upgrade go to RH-supported (and FIPS-compatible) version (#980) (Gregory Shilin)
- EDM-1039: Make CLI code Windows compatible (#951) (Gregory Shilin)
- EDM-1044: Add part 1 of hooks e2e tests and small disconnected adaptations (sserafin)
- NO-ISSUE: fix ppa-build (#985) (Gregory Shilin)
- NO-ISSUE: Update CLI login docs (rawagner)
- EDM-1025: Use ServiceHandler rather than Store in tasks (Avishay Traeger)
- EDM-759: Add provisioning, update image building (Frank A. Zdarsky)
- EDM-1245: Add versioning to Device Simulator (#984) (Gregory Shilin)
- NO-ISSUE: Ensure Git metadata persists correctly in Flightctl API build (#970) (Assaf Albo)
- EDM-1247: Use plural selectors for labels endpoint (#979) (Assaf Albo)
- EDM-1049: Add a global RequestTimeout flag to use in CLI commands (#924) (Gregory Shilin)
- EDM-1241: In disconnected env the token fails to be refreshed (Ori Amizur)
- NO-ISSUE: Add docs for decommissioning (Lily Sturmann)
- NO-ISSUE: Remove escapes, remove experimental (Frank A. Zdarsky)
- EDM-1192: Split transport and service layers (Avishay Traeger)
- EDM-1209: Fix token verification error for OR selectors (#966) (Assaf Albo)
- NO-ISSUE: Fix to disconnected-cluster.md (Eldar101)
- EDM-1213: Use alpine from quay.io (sserafin)
- EDM-1213: Replace e2eregistry docker image with flightctl quay.io copy (sserafin)
- EDM-1208: fix e2e cli tests in ocp and adjust timeout (sserafin)
- EDM-1172: Add disconnected clusters support to e2e test vm (sserafin)
- NO-ISSUE: Use redis from quay.io (rawagner)
- EDM-683: Add API for listing distinct device labels (#939) (Assaf Albo)
- EDM-1202: Fix missing Flightctl API Server version in upstream images (asafbss)
- NO-ISSUE: wrong dependencies in spec (Gregory Shilin)
- EDM-1195: Ensure that release-* branches create containers (#954) (Miguel Angel Ajo Pelayo)
- EDM-1191: docs/managing-devices: add section on pull secrets (Sam Batschelet)
- EDM-1178: API client should refresh expired token (Ori Amizur)
- EDM-1191: agent: ensure OS image pull uses ostree path (Sam Batschelet)
- EDM-1181: Update nameOrAlias selector in E2E test (amalykhi)
- NO-ISSUE: copying example yamls to test directory for testing purpose (amalykhi)
- EDM-1076: Improve docs for installing fctl on disconnected env (rawagner)
- EDM-1034: agent/hooks: add support for passing variables to hooks from inline cfg (Sam Batschelet)
- EDM-960: Validations of inline config (amalykhi)
- EDM-1181: ensure camelCase consistency in selector names (#936) (Assaf Albo)
- EDM-1048: api/validation: always validate image (Sam Batschelet)
- EDM-1047: api/validation: ensure whitespace is not valid for application name (Sam Batschelet)
- EDM-1049: CLI installed from RPM (COPR repo) and binary (GH) show the wrong version info (#925) (Gregory Shilin)
- NO-ISSUE: Update docs to refer to stable COPR repo (Frank A. Zdarsky)
- NO-ISSUE: Ensure that tags are treated as strings (rawagner)
- EDM-1176: Do not use images with floating tags (rawagner)
- EDM-1045: Adding E2E tests for finalizing parametrisable device templates (sserafin)
- EDM-1174: Use Authorization header instead of Authentication to align with HTTP spec (#918) (Rastislav Wagner)
- EDM-1168: Make --rendered flag return the full device (Frank A. Zdarsky)
- EDM-1160: docs: update stale references (Sam Batschelet)
- EDM-1160: api/vaidation: ensure consoles can not be added directly to device (Sam Batschelet)
- EDM-1160: *: react to api changes (Sam Batschelet)
- EDM-1160: api: add versioning to agent (Sam Batschelet)
- NO-ISSUE: Remove tar before re-creating it (#903) (Gregory Shilin)
- EDM-1112: pods pull from quay.io in disconnected env (#904) (Gregory Shilin)
- NO-ISSUE: Add API group to docs yamls (Avishay Traeger)
- NO-ISSUE: keep agent config naming consistent in getting started guide (Nick Cao)
- NO-ISSUE: Various user doc fixes (Frank A. Zdarsky)
- Update getting-started.md with Hyperlinks (Florian Moss)

* Thu May 1 2025 Lily Sturmann <lkatalin@users.noreply.github.com> - 0.6.0~main~207~g26a7845e-1.20250501163610897720.tpm.client.may.1.207.g26a7845e
- dkeje (Lily Sturmann)
- abc (Lily Sturmann)
- aseklg (Lily Sturmann)
- aseklg (Lily Sturmann)
- aseklj (Lily Sturmann)
- asej (Lily Sturmann)
- 29slky (Lily Sturmann)
- 29slkj (Lily Sturmann)
- skj (Lily Sturmann)
- fooo (Lily Sturmann)
- foooo (Lily Sturmann)
- d (Lily Sturmann)
- c (Lily Sturmann)
- b (Lily Sturmann)
- a (Lily Sturmann)
- fooO (Lily Sturmann)
- fooo (Lily Sturmann)
- foo (Lily Sturmann)
- bug fix wip 2 (Lily Sturmann)
- bug fix wip (Lily Sturmann)
- fake commit for systemd change (Lily Sturmann)
- EDM-1016: Add experimental feature to register TPM collection functions (Lily Sturmann)
- EDM-1016: Add TPM client agent-side (Lily Sturmann)
- EDM-1016: Fix for TPM system path (Lily Sturmann)
- EDM-1016: Include collector function data in system info (Lily Sturmann)
- NO-ISSUE: Remove --previous from kubectl log collection (Avishay Traeger)
- EDM-1315: Add events to create/update/delete APIs (Avishay Traeger)
- EDM-1275: Event retention (Avishay Traeger)
- EDM-1276: Add event listing to CLI (Avishay Traeger)
- NO-ISSUE: Fix selector resolving (Avishay Traeger)
- EDM-1274: Store system events in the database (Avishay Traeger)
- EDM-1276: Implement API to retrieve events (Avishay Traeger)
- EDM-1337: Modify nginx config to use only tls 1.3 (Dakota Crowder)
- EDM-1337: Change Warning err messages to Error (Dakota Crowder)
- EDM-1337: Modify rpm spec for install (Dakota Crowder)
- EDM-1337: Adjust setup to use default user for cli container (Dakota Crowder)
- EDM-1337: Install a flightctl-cli-artifacts quadlet (Dakota Crowder)
- EDM-1061: Add function to get TPM vendor info (Lily Sturmann)
- EDM-1435: agent/systemInfo: refactor and implement api (Sam Batschelet)
- EDM-1436: api: extend systemInfo status (Sam Batschelet)
- EDM-837: Document builds with RHEL base image (Frank A. Zdarsky)
- NO-ISSUE: Wrong code is generated for python (Gregory Shilin)
- EDM-1016: Add TPM functionality and unit tests to support attestation (Lily Sturmann)
- NO-ISSUE: Fixing Lint (Siddarth R)
- NO-ISSUE: Add ARM support for CPUInfo (Siddarth R)
- EDM-1333: refactoring to tests (Eldar Weiss)
- EDM-1453: agent: improve transient error handling (Sam Batschelet)
- EDM-1428: Add reload support for configuration changes (Ori Amizur)
- EDM-1452: Fix reference to ensure websocket handler is configured with middleware (Dakota Crowder)
- JIRA-1450:Incorrect Endpoint Used for CSR Approval (Siddarth Royapally)
- EDM-1429: agent: react to changes (Sam Batschelet)
- EDM-1429: agent: add systeminfo manager (Sam Batschelet)
- EDM-1429: agent: add system-info subcommand (Sam Batschelet)
- NO-ISSUE: Use printf rather than echo -e (Dakota Crowder)
- NO-ISSUE: Fix newline run-on issue with no bootc agent container (Dakota Crowder)
- Revert "EDM-1374: Resource monitorType casing mismatch causes alert not being displayed" (Sam Batschelet)
- EDM-1184: changed SELinux policy to allow systemd to start the service (Mario Parra)
- EDM-1367: Create aap oauth app from auth token (Dakota Crowder)
- NO-ISSUE: gRPC streams connections are disconnected after 5 minutes (Ori Amizur)
- EDM-1414: Add patch support for DeviceStatus (Sam Batschelet)
- NO-ISSUE: Revert removal o tags by https://github.com/flightctl/flightctl/pull/1013/ (#1088) (Gregory Shilin)
- EDM-1413: Break out get_services_for_tag function (Dakota Crowder)
- EDM-1413: Address image ref diff for ui images in dev builds (Dakota Crowder)
- EDM-1413: Add comment for ~ replacement context (Dakota Crowder)
- EDM-1413: Set image tag for installed quadlets based off of rpm version (Dakota Crowder)
- EDM-1314: docs: add inline compose details (Sam Batschelet)
- EDM-1295: Configuration for cli artifacts in UI standalone deployment (Celia Amador)
- EDM-1370: Add comment to .target explaining what the Requires and After diretives mean wrt startup ordering (Dakota Crowder)
- EDM-1288: Create sos report plugin for flightctl (Ori Amizur)
- EDM-1370: Remove redundant Wants from target (Dakota Crowder)
- EDM-1370: Run daemon-reload in post install (Dakota Crowder)
- EDM-1370: Improve service dependency mappings and use a .target instead of slice (Dakota Crowder)
- EDM-1333: adding coverage for more steps (Eldar Weiss)
- EDM-1374: Resource monitorType casing mismatch causes alert not being displayed (Sam Batschelet)
- NO-ISSUE: agent/os: only pull if not booted (Sam Batschelet)
- NO-ISSUE: Cleanup remnants from grpc endpoint previously surfaced at 7444 (Dakota Crowder)
- EDM-1186: Updates to quadlets config and rpm spec per feedback (Dakota Crowder)
- EDM-1186: RPM Quadlet Installer initial implementation (Dakota Crowder)
- EDM-1186: Use podman secrets to manage db and kv passwords (Dakota Crowder)
- EDM-1394: Revert "EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update" (#1080) (Assaf Albo)
- NO-ISSUE: Fixed minor issues with helm chart when using gateway API (Ram)
- NO-ISSUE: fix for login validation (amalykhi)
- NO-ISSUE: flightctl login validation test (amalykhi)
- EDM-1305:  Console enhancements (Ori Amizur)
- EDM-1313: agent: ensure update error condition is visible (Sam Batschelet)
- EDM-996: flightctl-agent rpm should create /etc/flightctl/ directory (#1069) (Gregory Shilin)
- EDM-1318: Bug fix removing client cert creation at startup (noga-magen)
- EDM-1320: api: improve compose spec validations (Sam Batschelet)
- NO-ISSUE: agent: improve initial sync timing (Sam Batschelet)
- EDM-889: Separate out auth provider config (Frank A. Zdarsky)
- EDM-889: Revert change in token serialization (Frank A. Zdarsky)
- EDM-889: Omit empty fields (Frank A. Zdarsky)
- NO-ISSUE: Added Note (Siddarth R)
- NO-ISSUE: Define global pull policy and use IfNotPresent (rawagner)
- EDM-1320: applications: improve provider validation (Sam Batschelet)
- EDM-1049: Use Stringer to format version (Frank A. Zdarsky)
- EDM-1049: Show field names when printing JSON and YAML output (Frank A. Zdarsky)
- EDM-1049: Enable use of context global flag (Frank A. Zdarsky)
- EDM-1354: In OCP flightctl-cli-artifacts pod is in CrashLoopBackOff installing with the latest helm chart (rawagner)
- EDM-1352: Building a gitserver as a root user fails (#1058) (Gregory Shilin)
- EDM-1294: Expose CLI Downloads via route and gateway. Create ConsoleCLIDownloads CR. (rawagner)
- EDM-1293: Deploy a pod with CLI tools (#1036) (Gregory Shilin)
- EDM-1329: agent/resource: calculate CPU usage with delta-based sampling (Sam Batschelet)
- EDM-1254: Add user documentation for rollout policies (Ori Amizur)
- EDM-1346: bump x/oauth2 and x/crypto (rawagner)
- EDM-1165: Fix AuthZ middleware. Add tests (rawagner)
- EDM-851: Update DevicesSummary to prevent null return (Siddarth R)
- Revert "EDM 851: Update DevicesSummary OpenAPI spec" (Siddarth R)
- EDM-1317: EDM-1321: api: add missing inline application eval (Sam Batschelet)
- EDM-310: Refactor CA handling (Anton Ivanov)
- NO-ISSUE: Update helm charts with new UI params (rawagner)
- EDM 851: Update DevicesSummary OpenAPI spec (Siddarth R)
- NO-ISSUE: Fix status e2e test (sserafin)
- NO-ISSUE: Anchors are not currently supported for workflows (#1013) (Gregory Shilin)
- EDM-1308: Use chi middleware request IDs (Avishay Traeger)
- EDM-1211: *: implement inline application provider (Sam Batschelet)
- EDM-1211: agent/applications: refactor (Sam Batschelet)
- EDM-1211: api: add application inline provider (Sam Batschelet)
- EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update (#1011) (Assaf Albo)
- EDM-1309: Prevent client from setting ER status (Avishay Traeger)
- EDM-1252:Adding labels (Eldar101)
- EDM-696: Support AAP Gateway OAuth2 (rawagner)
- NO-ISSUE: Make example enrollment request valid (Celia Amador)
- EDM-1214: Perform better validation of CSR and enrollment requests (Anton Ivanov)
- EDM-1251: fix JSONB fields in CompositeSelectorResolver (#995) (Assaf Albo)
- EDM-1138: Upgrade go to RH-supported (and FIPS-compatible) version (#980) (Gregory Shilin)
- EDM-1039: Make CLI code Windows compatible (#951) (Gregory Shilin)
- EDM-1044: Add part 1 of hooks e2e tests and small disconnected adaptations (sserafin)
- NO-ISSUE: fix ppa-build (#985) (Gregory Shilin)
- NO-ISSUE: Update CLI login docs (rawagner)
- EDM-1025: Use ServiceHandler rather than Store in tasks (Avishay Traeger)
- EDM-759: Add provisioning, update image building (Frank A. Zdarsky)
- EDM-1245: Add versioning to Device Simulator (#984) (Gregory Shilin)
- NO-ISSUE: Ensure Git metadata persists correctly in Flightctl API build (#970) (Assaf Albo)
- EDM-1247: Use plural selectors for labels endpoint (#979) (Assaf Albo)
- EDM-1049: Add a global RequestTimeout flag to use in CLI commands (#924) (Gregory Shilin)
- EDM-1241: In disconnected env the token fails to be refreshed (Ori Amizur)
- NO-ISSUE: Add docs for decommissioning (Lily Sturmann)
- NO-ISSUE: Remove escapes, remove experimental (Frank A. Zdarsky)
- EDM-1192: Split transport and service layers (Avishay Traeger)
- EDM-1209: Fix token verification error for OR selectors (#966) (Assaf Albo)
- NO-ISSUE: Fix to disconnected-cluster.md (Eldar101)
- EDM-1213: Use alpine from quay.io (sserafin)
- EDM-1213: Replace e2eregistry docker image with flightctl quay.io copy (sserafin)
- EDM-1208: fix e2e cli tests in ocp and adjust timeout (sserafin)
- EDM-1172: Add disconnected clusters support to e2e test vm (sserafin)
- NO-ISSUE: Use redis from quay.io (rawagner)
- EDM-683: Add API for listing distinct device labels (#939) (Assaf Albo)
- EDM-1202: Fix missing Flightctl API Server version in upstream images (asafbss)
- NO-ISSUE: wrong dependencies in spec (Gregory Shilin)
- EDM-1195: Ensure that release-* branches create containers (#954) (Miguel Angel Ajo Pelayo)
- EDM-1191: docs/managing-devices: add section on pull secrets (Sam Batschelet)
- EDM-1178: API client should refresh expired token (Ori Amizur)
- EDM-1191: agent: ensure OS image pull uses ostree path (Sam Batschelet)
- EDM-1181: Update nameOrAlias selector in E2E test (amalykhi)
- NO-ISSUE: copying example yamls to test directory for testing purpose (amalykhi)
- EDM-1076: Improve docs for installing fctl on disconnected env (rawagner)
- EDM-1034: agent/hooks: add support for passing variables to hooks from inline cfg (Sam Batschelet)
- EDM-960: Validations of inline config (amalykhi)
- EDM-1181: ensure camelCase consistency in selector names (#936) (Assaf Albo)
- EDM-1048: api/validation: always validate image (Sam Batschelet)
- EDM-1047: api/validation: ensure whitespace is not valid for application name (Sam Batschelet)
- EDM-1049: CLI installed from RPM (COPR repo) and binary (GH) show the wrong version info (#925) (Gregory Shilin)
- NO-ISSUE: Update docs to refer to stable COPR repo (Frank A. Zdarsky)
- NO-ISSUE: Ensure that tags are treated as strings (rawagner)
- EDM-1176: Do not use images with floating tags (rawagner)
- EDM-1045: Adding E2E tests for finalizing parametrisable device templates (sserafin)
- EDM-1174: Use Authorization header instead of Authentication to align with HTTP spec (#918) (Rastislav Wagner)
- EDM-1168: Make --rendered flag return the full device (Frank A. Zdarsky)
- EDM-1160: docs: update stale references (Sam Batschelet)
- EDM-1160: api/vaidation: ensure consoles can not be added directly to device (Sam Batschelet)
- EDM-1160: *: react to api changes (Sam Batschelet)
- EDM-1160: api: add versioning to agent (Sam Batschelet)
- NO-ISSUE: Remove tar before re-creating it (#903) (Gregory Shilin)
- EDM-1112: pods pull from quay.io in disconnected env (#904) (Gregory Shilin)
- NO-ISSUE: Add API group to docs yamls (Avishay Traeger)
- NO-ISSUE: keep agent config naming consistent in getting started guide (Nick Cao)
- NO-ISSUE: Various user doc fixes (Frank A. Zdarsky)
- Update getting-started.md with Hyperlinks (Florian Moss)

* Thu May 1 2025 Lily Sturmann <lkatalin@users.noreply.github.com> - 0.6.0~main~207~g26a7845e-1.20250501163337334876.tpm.client.may.1.207.g26a7845e
- dkeje (Lily Sturmann)
- abc (Lily Sturmann)
- aseklg (Lily Sturmann)
- aseklg (Lily Sturmann)
- aseklj (Lily Sturmann)
- asej (Lily Sturmann)
- 29slky (Lily Sturmann)
- 29slkj (Lily Sturmann)
- skj (Lily Sturmann)
- fooo (Lily Sturmann)
- foooo (Lily Sturmann)
- d (Lily Sturmann)
- c (Lily Sturmann)
- b (Lily Sturmann)
- a (Lily Sturmann)
- fooO (Lily Sturmann)
- fooo (Lily Sturmann)
- foo (Lily Sturmann)
- bug fix wip 2 (Lily Sturmann)
- bug fix wip (Lily Sturmann)
- fake commit for systemd change (Lily Sturmann)
- EDM-1016: Add experimental feature to register TPM collection functions (Lily Sturmann)
- EDM-1016: Add TPM client agent-side (Lily Sturmann)
- EDM-1016: Fix for TPM system path (Lily Sturmann)
- EDM-1016: Include collector function data in system info (Lily Sturmann)
- NO-ISSUE: Remove --previous from kubectl log collection (Avishay Traeger)
- EDM-1315: Add events to create/update/delete APIs (Avishay Traeger)
- EDM-1275: Event retention (Avishay Traeger)
- EDM-1276: Add event listing to CLI (Avishay Traeger)
- NO-ISSUE: Fix selector resolving (Avishay Traeger)
- EDM-1274: Store system events in the database (Avishay Traeger)
- EDM-1276: Implement API to retrieve events (Avishay Traeger)
- EDM-1337: Modify nginx config to use only tls 1.3 (Dakota Crowder)
- EDM-1337: Change Warning err messages to Error (Dakota Crowder)
- EDM-1337: Modify rpm spec for install (Dakota Crowder)
- EDM-1337: Adjust setup to use default user for cli container (Dakota Crowder)
- EDM-1337: Install a flightctl-cli-artifacts quadlet (Dakota Crowder)
- EDM-1061: Add function to get TPM vendor info (Lily Sturmann)
- EDM-1435: agent/systemInfo: refactor and implement api (Sam Batschelet)
- EDM-1436: api: extend systemInfo status (Sam Batschelet)
- EDM-837: Document builds with RHEL base image (Frank A. Zdarsky)
- NO-ISSUE: Wrong code is generated for python (Gregory Shilin)
- EDM-1016: Add TPM functionality and unit tests to support attestation (Lily Sturmann)
- NO-ISSUE: Fixing Lint (Siddarth R)
- NO-ISSUE: Add ARM support for CPUInfo (Siddarth R)
- EDM-1333: refactoring to tests (Eldar Weiss)
- EDM-1453: agent: improve transient error handling (Sam Batschelet)
- EDM-1428: Add reload support for configuration changes (Ori Amizur)
- EDM-1452: Fix reference to ensure websocket handler is configured with middleware (Dakota Crowder)
- JIRA-1450:Incorrect Endpoint Used for CSR Approval (Siddarth Royapally)
- EDM-1429: agent: react to changes (Sam Batschelet)
- EDM-1429: agent: add systeminfo manager (Sam Batschelet)
- EDM-1429: agent: add system-info subcommand (Sam Batschelet)
- NO-ISSUE: Use printf rather than echo -e (Dakota Crowder)
- NO-ISSUE: Fix newline run-on issue with no bootc agent container (Dakota Crowder)
- Revert "EDM-1374: Resource monitorType casing mismatch causes alert not being displayed" (Sam Batschelet)
- EDM-1184: changed SELinux policy to allow systemd to start the service (Mario Parra)
- EDM-1367: Create aap oauth app from auth token (Dakota Crowder)
- NO-ISSUE: gRPC streams connections are disconnected after 5 minutes (Ori Amizur)
- EDM-1414: Add patch support for DeviceStatus (Sam Batschelet)
- NO-ISSUE: Revert removal o tags by https://github.com/flightctl/flightctl/pull/1013/ (#1088) (Gregory Shilin)
- EDM-1413: Break out get_services_for_tag function (Dakota Crowder)
- EDM-1413: Address image ref diff for ui images in dev builds (Dakota Crowder)
- EDM-1413: Add comment for ~ replacement context (Dakota Crowder)
- EDM-1413: Set image tag for installed quadlets based off of rpm version (Dakota Crowder)
- EDM-1314: docs: add inline compose details (Sam Batschelet)
- EDM-1295: Configuration for cli artifacts in UI standalone deployment (Celia Amador)
- EDM-1370: Add comment to .target explaining what the Requires and After diretives mean wrt startup ordering (Dakota Crowder)
- EDM-1288: Create sos report plugin for flightctl (Ori Amizur)
- EDM-1370: Remove redundant Wants from target (Dakota Crowder)
- EDM-1370: Run daemon-reload in post install (Dakota Crowder)
- EDM-1370: Improve service dependency mappings and use a .target instead of slice (Dakota Crowder)
- EDM-1333: adding coverage for more steps (Eldar Weiss)
- EDM-1374: Resource monitorType casing mismatch causes alert not being displayed (Sam Batschelet)
- NO-ISSUE: agent/os: only pull if not booted (Sam Batschelet)
- NO-ISSUE: Cleanup remnants from grpc endpoint previously surfaced at 7444 (Dakota Crowder)
- EDM-1186: Updates to quadlets config and rpm spec per feedback (Dakota Crowder)
- EDM-1186: RPM Quadlet Installer initial implementation (Dakota Crowder)
- EDM-1186: Use podman secrets to manage db and kv passwords (Dakota Crowder)
- EDM-1394: Revert "EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update" (#1080) (Assaf Albo)
- NO-ISSUE: Fixed minor issues with helm chart when using gateway API (Ram)
- NO-ISSUE: fix for login validation (amalykhi)
- NO-ISSUE: flightctl login validation test (amalykhi)
- EDM-1305:  Console enhancements (Ori Amizur)
- EDM-1313: agent: ensure update error condition is visible (Sam Batschelet)
- EDM-996: flightctl-agent rpm should create /etc/flightctl/ directory (#1069) (Gregory Shilin)
- EDM-1318: Bug fix removing client cert creation at startup (noga-magen)
- EDM-1320: api: improve compose spec validations (Sam Batschelet)
- NO-ISSUE: agent: improve initial sync timing (Sam Batschelet)
- EDM-889: Separate out auth provider config (Frank A. Zdarsky)
- EDM-889: Revert change in token serialization (Frank A. Zdarsky)
- EDM-889: Omit empty fields (Frank A. Zdarsky)
- NO-ISSUE: Added Note (Siddarth R)
- NO-ISSUE: Define global pull policy and use IfNotPresent (rawagner)
- EDM-1320: applications: improve provider validation (Sam Batschelet)
- EDM-1049: Use Stringer to format version (Frank A. Zdarsky)
- EDM-1049: Show field names when printing JSON and YAML output (Frank A. Zdarsky)
- EDM-1049: Enable use of context global flag (Frank A. Zdarsky)
- EDM-1354: In OCP flightctl-cli-artifacts pod is in CrashLoopBackOff installing with the latest helm chart (rawagner)
- EDM-1352: Building a gitserver as a root user fails (#1058) (Gregory Shilin)
- EDM-1294: Expose CLI Downloads via route and gateway. Create ConsoleCLIDownloads CR. (rawagner)
- EDM-1293: Deploy a pod with CLI tools (#1036) (Gregory Shilin)
- EDM-1329: agent/resource: calculate CPU usage with delta-based sampling (Sam Batschelet)
- EDM-1254: Add user documentation for rollout policies (Ori Amizur)
- EDM-1346: bump x/oauth2 and x/crypto (rawagner)
- EDM-1165: Fix AuthZ middleware. Add tests (rawagner)
- EDM-851: Update DevicesSummary to prevent null return (Siddarth R)
- Revert "EDM 851: Update DevicesSummary OpenAPI spec" (Siddarth R)
- EDM-1317: EDM-1321: api: add missing inline application eval (Sam Batschelet)
- EDM-310: Refactor CA handling (Anton Ivanov)
- NO-ISSUE: Update helm charts with new UI params (rawagner)
- EDM 851: Update DevicesSummary OpenAPI spec (Siddarth R)
- NO-ISSUE: Fix status e2e test (sserafin)
- NO-ISSUE: Anchors are not currently supported for workflows (#1013) (Gregory Shilin)
- EDM-1308: Use chi middleware request IDs (Avishay Traeger)
- EDM-1211: *: implement inline application provider (Sam Batschelet)
- EDM-1211: agent/applications: refactor (Sam Batschelet)
- EDM-1211: api: add application inline provider (Sam Batschelet)
- EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update (#1011) (Assaf Albo)
- EDM-1309: Prevent client from setting ER status (Avishay Traeger)
- EDM-1252:Adding labels (Eldar101)
- EDM-696: Support AAP Gateway OAuth2 (rawagner)
- NO-ISSUE: Make example enrollment request valid (Celia Amador)
- EDM-1214: Perform better validation of CSR and enrollment requests (Anton Ivanov)
- EDM-1251: fix JSONB fields in CompositeSelectorResolver (#995) (Assaf Albo)
- EDM-1138: Upgrade go to RH-supported (and FIPS-compatible) version (#980) (Gregory Shilin)
- EDM-1039: Make CLI code Windows compatible (#951) (Gregory Shilin)
- EDM-1044: Add part 1 of hooks e2e tests and small disconnected adaptations (sserafin)
- NO-ISSUE: fix ppa-build (#985) (Gregory Shilin)
- NO-ISSUE: Update CLI login docs (rawagner)
- EDM-1025: Use ServiceHandler rather than Store in tasks (Avishay Traeger)
- EDM-759: Add provisioning, update image building (Frank A. Zdarsky)
- EDM-1245: Add versioning to Device Simulator (#984) (Gregory Shilin)
- NO-ISSUE: Ensure Git metadata persists correctly in Flightctl API build (#970) (Assaf Albo)
- EDM-1247: Use plural selectors for labels endpoint (#979) (Assaf Albo)
- EDM-1049: Add a global RequestTimeout flag to use in CLI commands (#924) (Gregory Shilin)
- EDM-1241: In disconnected env the token fails to be refreshed (Ori Amizur)
- NO-ISSUE: Add docs for decommissioning (Lily Sturmann)
- NO-ISSUE: Remove escapes, remove experimental (Frank A. Zdarsky)
- EDM-1192: Split transport and service layers (Avishay Traeger)
- EDM-1209: Fix token verification error for OR selectors (#966) (Assaf Albo)
- NO-ISSUE: Fix to disconnected-cluster.md (Eldar101)
- EDM-1213: Use alpine from quay.io (sserafin)
- EDM-1213: Replace e2eregistry docker image with flightctl quay.io copy (sserafin)
- EDM-1208: fix e2e cli tests in ocp and adjust timeout (sserafin)
- EDM-1172: Add disconnected clusters support to e2e test vm (sserafin)
- NO-ISSUE: Use redis from quay.io (rawagner)
- EDM-683: Add API for listing distinct device labels (#939) (Assaf Albo)
- EDM-1202: Fix missing Flightctl API Server version in upstream images (asafbss)
- NO-ISSUE: wrong dependencies in spec (Gregory Shilin)
- EDM-1195: Ensure that release-* branches create containers (#954) (Miguel Angel Ajo Pelayo)
- EDM-1191: docs/managing-devices: add section on pull secrets (Sam Batschelet)
- EDM-1178: API client should refresh expired token (Ori Amizur)
- EDM-1191: agent: ensure OS image pull uses ostree path (Sam Batschelet)
- EDM-1181: Update nameOrAlias selector in E2E test (amalykhi)
- NO-ISSUE: copying example yamls to test directory for testing purpose (amalykhi)
- EDM-1076: Improve docs for installing fctl on disconnected env (rawagner)
- EDM-1034: agent/hooks: add support for passing variables to hooks from inline cfg (Sam Batschelet)
- EDM-960: Validations of inline config (amalykhi)
- EDM-1181: ensure camelCase consistency in selector names (#936) (Assaf Albo)
- EDM-1048: api/validation: always validate image (Sam Batschelet)
- EDM-1047: api/validation: ensure whitespace is not valid for application name (Sam Batschelet)
- EDM-1049: CLI installed from RPM (COPR repo) and binary (GH) show the wrong version info (#925) (Gregory Shilin)
- NO-ISSUE: Update docs to refer to stable COPR repo (Frank A. Zdarsky)
- NO-ISSUE: Ensure that tags are treated as strings (rawagner)
- EDM-1176: Do not use images with floating tags (rawagner)
- EDM-1045: Adding E2E tests for finalizing parametrisable device templates (sserafin)
- EDM-1174: Use Authorization header instead of Authentication to align with HTTP spec (#918) (Rastislav Wagner)
- EDM-1168: Make --rendered flag return the full device (Frank A. Zdarsky)
- EDM-1160: docs: update stale references (Sam Batschelet)
- EDM-1160: api/vaidation: ensure consoles can not be added directly to device (Sam Batschelet)
- EDM-1160: *: react to api changes (Sam Batschelet)
- EDM-1160: api: add versioning to agent (Sam Batschelet)
- NO-ISSUE: Remove tar before re-creating it (#903) (Gregory Shilin)
- EDM-1112: pods pull from quay.io in disconnected env (#904) (Gregory Shilin)
- NO-ISSUE: Add API group to docs yamls (Avishay Traeger)
- NO-ISSUE: keep agent config naming consistent in getting started guide (Nick Cao)
- NO-ISSUE: Various user doc fixes (Frank A. Zdarsky)
- Update getting-started.md with Hyperlinks (Florian Moss)

* Thu May 1 2025 Lily Sturmann <lkatalin@users.noreply.github.com> - 0.6.0~main~204~g81eab885-1.20250501155708471685.tpm.client.may.1.204.g81eab885
- aseklg (Lily Sturmann)
- aseklj (Lily Sturmann)
- asej (Lily Sturmann)
- 29slky (Lily Sturmann)
- 29slkj (Lily Sturmann)
- skj (Lily Sturmann)
- fooo (Lily Sturmann)
- foooo (Lily Sturmann)
- d (Lily Sturmann)
- c (Lily Sturmann)
- b (Lily Sturmann)
- a (Lily Sturmann)
- fooO (Lily Sturmann)
- fooo (Lily Sturmann)
- foo (Lily Sturmann)
- bug fix wip 2 (Lily Sturmann)
- bug fix wip (Lily Sturmann)
- fake commit for systemd change (Lily Sturmann)
- EDM-1016: Add experimental feature to register TPM collection functions (Lily Sturmann)
- EDM-1016: Add TPM client agent-side (Lily Sturmann)
- EDM-1016: Fix for TPM system path (Lily Sturmann)
- EDM-1016: Include collector function data in system info (Lily Sturmann)
- NO-ISSUE: Remove --previous from kubectl log collection (Avishay Traeger)
- EDM-1315: Add events to create/update/delete APIs (Avishay Traeger)
- EDM-1275: Event retention (Avishay Traeger)
- EDM-1276: Add event listing to CLI (Avishay Traeger)
- NO-ISSUE: Fix selector resolving (Avishay Traeger)
- EDM-1274: Store system events in the database (Avishay Traeger)
- EDM-1276: Implement API to retrieve events (Avishay Traeger)
- EDM-1337: Modify nginx config to use only tls 1.3 (Dakota Crowder)
- EDM-1337: Change Warning err messages to Error (Dakota Crowder)
- EDM-1337: Modify rpm spec for install (Dakota Crowder)
- EDM-1337: Adjust setup to use default user for cli container (Dakota Crowder)
- EDM-1337: Install a flightctl-cli-artifacts quadlet (Dakota Crowder)
- EDM-1061: Add function to get TPM vendor info (Lily Sturmann)
- EDM-1435: agent/systemInfo: refactor and implement api (Sam Batschelet)
- EDM-1436: api: extend systemInfo status (Sam Batschelet)
- EDM-837: Document builds with RHEL base image (Frank A. Zdarsky)
- NO-ISSUE: Wrong code is generated for python (Gregory Shilin)
- EDM-1016: Add TPM functionality and unit tests to support attestation (Lily Sturmann)
- NO-ISSUE: Fixing Lint (Siddarth R)
- NO-ISSUE: Add ARM support for CPUInfo (Siddarth R)
- EDM-1333: refactoring to tests (Eldar Weiss)
- EDM-1453: agent: improve transient error handling (Sam Batschelet)
- EDM-1428: Add reload support for configuration changes (Ori Amizur)
- EDM-1452: Fix reference to ensure websocket handler is configured with middleware (Dakota Crowder)
- JIRA-1450:Incorrect Endpoint Used for CSR Approval (Siddarth Royapally)
- EDM-1429: agent: react to changes (Sam Batschelet)
- EDM-1429: agent: add systeminfo manager (Sam Batschelet)
- EDM-1429: agent: add system-info subcommand (Sam Batschelet)
- NO-ISSUE: Use printf rather than echo -e (Dakota Crowder)
- NO-ISSUE: Fix newline run-on issue with no bootc agent container (Dakota Crowder)
- Revert "EDM-1374: Resource monitorType casing mismatch causes alert not being displayed" (Sam Batschelet)
- EDM-1184: changed SELinux policy to allow systemd to start the service (Mario Parra)
- EDM-1367: Create aap oauth app from auth token (Dakota Crowder)
- NO-ISSUE: gRPC streams connections are disconnected after 5 minutes (Ori Amizur)
- EDM-1414: Add patch support for DeviceStatus (Sam Batschelet)
- NO-ISSUE: Revert removal o tags by https://github.com/flightctl/flightctl/pull/1013/ (#1088) (Gregory Shilin)
- EDM-1413: Break out get_services_for_tag function (Dakota Crowder)
- EDM-1413: Address image ref diff for ui images in dev builds (Dakota Crowder)
- EDM-1413: Add comment for ~ replacement context (Dakota Crowder)
- EDM-1413: Set image tag for installed quadlets based off of rpm version (Dakota Crowder)
- EDM-1314: docs: add inline compose details (Sam Batschelet)
- EDM-1295: Configuration for cli artifacts in UI standalone deployment (Celia Amador)
- EDM-1370: Add comment to .target explaining what the Requires and After diretives mean wrt startup ordering (Dakota Crowder)
- EDM-1288: Create sos report plugin for flightctl (Ori Amizur)
- EDM-1370: Remove redundant Wants from target (Dakota Crowder)
- EDM-1370: Run daemon-reload in post install (Dakota Crowder)
- EDM-1370: Improve service dependency mappings and use a .target instead of slice (Dakota Crowder)
- EDM-1333: adding coverage for more steps (Eldar Weiss)
- EDM-1374: Resource monitorType casing mismatch causes alert not being displayed (Sam Batschelet)
- NO-ISSUE: agent/os: only pull if not booted (Sam Batschelet)
- NO-ISSUE: Cleanup remnants from grpc endpoint previously surfaced at 7444 (Dakota Crowder)
- EDM-1186: Updates to quadlets config and rpm spec per feedback (Dakota Crowder)
- EDM-1186: RPM Quadlet Installer initial implementation (Dakota Crowder)
- EDM-1186: Use podman secrets to manage db and kv passwords (Dakota Crowder)
- EDM-1394: Revert "EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update" (#1080) (Assaf Albo)
- NO-ISSUE: Fixed minor issues with helm chart when using gateway API (Ram)
- NO-ISSUE: fix for login validation (amalykhi)
- NO-ISSUE: flightctl login validation test (amalykhi)
- EDM-1305:  Console enhancements (Ori Amizur)
- EDM-1313: agent: ensure update error condition is visible (Sam Batschelet)
- EDM-996: flightctl-agent rpm should create /etc/flightctl/ directory (#1069) (Gregory Shilin)
- EDM-1318: Bug fix removing client cert creation at startup (noga-magen)
- EDM-1320: api: improve compose spec validations (Sam Batschelet)
- NO-ISSUE: agent: improve initial sync timing (Sam Batschelet)
- EDM-889: Separate out auth provider config (Frank A. Zdarsky)
- EDM-889: Revert change in token serialization (Frank A. Zdarsky)
- EDM-889: Omit empty fields (Frank A. Zdarsky)
- NO-ISSUE: Added Note (Siddarth R)
- NO-ISSUE: Define global pull policy and use IfNotPresent (rawagner)
- EDM-1320: applications: improve provider validation (Sam Batschelet)
- EDM-1049: Use Stringer to format version (Frank A. Zdarsky)
- EDM-1049: Show field names when printing JSON and YAML output (Frank A. Zdarsky)
- EDM-1049: Enable use of context global flag (Frank A. Zdarsky)
- EDM-1354: In OCP flightctl-cli-artifacts pod is in CrashLoopBackOff installing with the latest helm chart (rawagner)
- EDM-1352: Building a gitserver as a root user fails (#1058) (Gregory Shilin)
- EDM-1294: Expose CLI Downloads via route and gateway. Create ConsoleCLIDownloads CR. (rawagner)
- EDM-1293: Deploy a pod with CLI tools (#1036) (Gregory Shilin)
- EDM-1329: agent/resource: calculate CPU usage with delta-based sampling (Sam Batschelet)
- EDM-1254: Add user documentation for rollout policies (Ori Amizur)
- EDM-1346: bump x/oauth2 and x/crypto (rawagner)
- EDM-1165: Fix AuthZ middleware. Add tests (rawagner)
- EDM-851: Update DevicesSummary to prevent null return (Siddarth R)
- Revert "EDM 851: Update DevicesSummary OpenAPI spec" (Siddarth R)
- EDM-1317: EDM-1321: api: add missing inline application eval (Sam Batschelet)
- EDM-310: Refactor CA handling (Anton Ivanov)
- NO-ISSUE: Update helm charts with new UI params (rawagner)
- EDM 851: Update DevicesSummary OpenAPI spec (Siddarth R)
- NO-ISSUE: Fix status e2e test (sserafin)
- NO-ISSUE: Anchors are not currently supported for workflows (#1013) (Gregory Shilin)
- EDM-1308: Use chi middleware request IDs (Avishay Traeger)
- EDM-1211: *: implement inline application provider (Sam Batschelet)
- EDM-1211: agent/applications: refactor (Sam Batschelet)
- EDM-1211: api: add application inline provider (Sam Batschelet)
- EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update (#1011) (Assaf Albo)
- EDM-1309: Prevent client from setting ER status (Avishay Traeger)
- EDM-1252:Adding labels (Eldar101)
- EDM-696: Support AAP Gateway OAuth2 (rawagner)
- NO-ISSUE: Make example enrollment request valid (Celia Amador)
- EDM-1214: Perform better validation of CSR and enrollment requests (Anton Ivanov)
- EDM-1251: fix JSONB fields in CompositeSelectorResolver (#995) (Assaf Albo)
- EDM-1138: Upgrade go to RH-supported (and FIPS-compatible) version (#980) (Gregory Shilin)
- EDM-1039: Make CLI code Windows compatible (#951) (Gregory Shilin)
- EDM-1044: Add part 1 of hooks e2e tests and small disconnected adaptations (sserafin)
- NO-ISSUE: fix ppa-build (#985) (Gregory Shilin)
- NO-ISSUE: Update CLI login docs (rawagner)
- EDM-1025: Use ServiceHandler rather than Store in tasks (Avishay Traeger)
- EDM-759: Add provisioning, update image building (Frank A. Zdarsky)
- EDM-1245: Add versioning to Device Simulator (#984) (Gregory Shilin)
- NO-ISSUE: Ensure Git metadata persists correctly in Flightctl API build (#970) (Assaf Albo)
- EDM-1247: Use plural selectors for labels endpoint (#979) (Assaf Albo)
- EDM-1049: Add a global RequestTimeout flag to use in CLI commands (#924) (Gregory Shilin)
- EDM-1241: In disconnected env the token fails to be refreshed (Ori Amizur)
- NO-ISSUE: Add docs for decommissioning (Lily Sturmann)
- NO-ISSUE: Remove escapes, remove experimental (Frank A. Zdarsky)
- EDM-1192: Split transport and service layers (Avishay Traeger)
- EDM-1209: Fix token verification error for OR selectors (#966) (Assaf Albo)
- NO-ISSUE: Fix to disconnected-cluster.md (Eldar101)
- EDM-1213: Use alpine from quay.io (sserafin)
- EDM-1213: Replace e2eregistry docker image with flightctl quay.io copy (sserafin)
- EDM-1208: fix e2e cli tests in ocp and adjust timeout (sserafin)
- EDM-1172: Add disconnected clusters support to e2e test vm (sserafin)
- NO-ISSUE: Use redis from quay.io (rawagner)
- EDM-683: Add API for listing distinct device labels (#939) (Assaf Albo)
- EDM-1202: Fix missing Flightctl API Server version in upstream images (asafbss)
- NO-ISSUE: wrong dependencies in spec (Gregory Shilin)
- EDM-1195: Ensure that release-* branches create containers (#954) (Miguel Angel Ajo Pelayo)
- EDM-1191: docs/managing-devices: add section on pull secrets (Sam Batschelet)
- EDM-1178: API client should refresh expired token (Ori Amizur)
- EDM-1191: agent: ensure OS image pull uses ostree path (Sam Batschelet)
- EDM-1181: Update nameOrAlias selector in E2E test (amalykhi)
- NO-ISSUE: copying example yamls to test directory for testing purpose (amalykhi)
- EDM-1076: Improve docs for installing fctl on disconnected env (rawagner)
- EDM-1034: agent/hooks: add support for passing variables to hooks from inline cfg (Sam Batschelet)
- EDM-960: Validations of inline config (amalykhi)
- EDM-1181: ensure camelCase consistency in selector names (#936) (Assaf Albo)
- EDM-1048: api/validation: always validate image (Sam Batschelet)
- EDM-1047: api/validation: ensure whitespace is not valid for application name (Sam Batschelet)
- EDM-1049: CLI installed from RPM (COPR repo) and binary (GH) show the wrong version info (#925) (Gregory Shilin)
- NO-ISSUE: Update docs to refer to stable COPR repo (Frank A. Zdarsky)
- NO-ISSUE: Ensure that tags are treated as strings (rawagner)
- EDM-1176: Do not use images with floating tags (rawagner)
- EDM-1045: Adding E2E tests for finalizing parametrisable device templates (sserafin)
- EDM-1174: Use Authorization header instead of Authentication to align with HTTP spec (#918) (Rastislav Wagner)
- EDM-1168: Make --rendered flag return the full device (Frank A. Zdarsky)
- EDM-1160: docs: update stale references (Sam Batschelet)
- EDM-1160: api/vaidation: ensure consoles can not be added directly to device (Sam Batschelet)
- EDM-1160: *: react to api changes (Sam Batschelet)
- EDM-1160: api: add versioning to agent (Sam Batschelet)
- NO-ISSUE: Remove tar before re-creating it (#903) (Gregory Shilin)
- EDM-1112: pods pull from quay.io in disconnected env (#904) (Gregory Shilin)
- NO-ISSUE: Add API group to docs yamls (Avishay Traeger)
- NO-ISSUE: keep agent config naming consistent in getting started guide (Nick Cao)
- NO-ISSUE: Various user doc fixes (Frank A. Zdarsky)
- Update getting-started.md with Hyperlinks (Florian Moss)

* Thu May 1 2025 Lily Sturmann <lkatalin@users.noreply.github.com> - 0.6.0~main~203~g5db715f9-1.20250501155612016115.tpm.client.may.1.203.g5db715f9
- aseklj (Lily Sturmann)
- asej (Lily Sturmann)
- 29slky (Lily Sturmann)
- 29slkj (Lily Sturmann)
- skj (Lily Sturmann)
- fooo (Lily Sturmann)
- foooo (Lily Sturmann)
- d (Lily Sturmann)
- c (Lily Sturmann)
- b (Lily Sturmann)
- a (Lily Sturmann)
- fooO (Lily Sturmann)
- fooo (Lily Sturmann)
- foo (Lily Sturmann)
- bug fix wip 2 (Lily Sturmann)
- bug fix wip (Lily Sturmann)
- fake commit for systemd change (Lily Sturmann)
- EDM-1016: Add experimental feature to register TPM collection functions (Lily Sturmann)
- EDM-1016: Add TPM client agent-side (Lily Sturmann)
- EDM-1016: Fix for TPM system path (Lily Sturmann)
- EDM-1016: Include collector function data in system info (Lily Sturmann)
- NO-ISSUE: Remove --previous from kubectl log collection (Avishay Traeger)
- EDM-1315: Add events to create/update/delete APIs (Avishay Traeger)
- EDM-1275: Event retention (Avishay Traeger)
- EDM-1276: Add event listing to CLI (Avishay Traeger)
- NO-ISSUE: Fix selector resolving (Avishay Traeger)
- EDM-1274: Store system events in the database (Avishay Traeger)
- EDM-1276: Implement API to retrieve events (Avishay Traeger)
- EDM-1337: Modify nginx config to use only tls 1.3 (Dakota Crowder)
- EDM-1337: Change Warning err messages to Error (Dakota Crowder)
- EDM-1337: Modify rpm spec for install (Dakota Crowder)
- EDM-1337: Adjust setup to use default user for cli container (Dakota Crowder)
- EDM-1337: Install a flightctl-cli-artifacts quadlet (Dakota Crowder)
- EDM-1061: Add function to get TPM vendor info (Lily Sturmann)
- EDM-1435: agent/systemInfo: refactor and implement api (Sam Batschelet)
- EDM-1436: api: extend systemInfo status (Sam Batschelet)
- EDM-837: Document builds with RHEL base image (Frank A. Zdarsky)
- NO-ISSUE: Wrong code is generated for python (Gregory Shilin)
- EDM-1016: Add TPM functionality and unit tests to support attestation (Lily Sturmann)
- NO-ISSUE: Fixing Lint (Siddarth R)
- NO-ISSUE: Add ARM support for CPUInfo (Siddarth R)
- EDM-1333: refactoring to tests (Eldar Weiss)
- EDM-1453: agent: improve transient error handling (Sam Batschelet)
- EDM-1428: Add reload support for configuration changes (Ori Amizur)
- EDM-1452: Fix reference to ensure websocket handler is configured with middleware (Dakota Crowder)
- JIRA-1450:Incorrect Endpoint Used for CSR Approval (Siddarth Royapally)
- EDM-1429: agent: react to changes (Sam Batschelet)
- EDM-1429: agent: add systeminfo manager (Sam Batschelet)
- EDM-1429: agent: add system-info subcommand (Sam Batschelet)
- NO-ISSUE: Use printf rather than echo -e (Dakota Crowder)
- NO-ISSUE: Fix newline run-on issue with no bootc agent container (Dakota Crowder)
- Revert "EDM-1374: Resource monitorType casing mismatch causes alert not being displayed" (Sam Batschelet)
- EDM-1184: changed SELinux policy to allow systemd to start the service (Mario Parra)
- EDM-1367: Create aap oauth app from auth token (Dakota Crowder)
- NO-ISSUE: gRPC streams connections are disconnected after 5 minutes (Ori Amizur)
- EDM-1414: Add patch support for DeviceStatus (Sam Batschelet)
- NO-ISSUE: Revert removal o tags by https://github.com/flightctl/flightctl/pull/1013/ (#1088) (Gregory Shilin)
- EDM-1413: Break out get_services_for_tag function (Dakota Crowder)
- EDM-1413: Address image ref diff for ui images in dev builds (Dakota Crowder)
- EDM-1413: Add comment for ~ replacement context (Dakota Crowder)
- EDM-1413: Set image tag for installed quadlets based off of rpm version (Dakota Crowder)
- EDM-1314: docs: add inline compose details (Sam Batschelet)
- EDM-1295: Configuration for cli artifacts in UI standalone deployment (Celia Amador)
- EDM-1370: Add comment to .target explaining what the Requires and After diretives mean wrt startup ordering (Dakota Crowder)
- EDM-1288: Create sos report plugin for flightctl (Ori Amizur)
- EDM-1370: Remove redundant Wants from target (Dakota Crowder)
- EDM-1370: Run daemon-reload in post install (Dakota Crowder)
- EDM-1370: Improve service dependency mappings and use a .target instead of slice (Dakota Crowder)
- EDM-1333: adding coverage for more steps (Eldar Weiss)
- EDM-1374: Resource monitorType casing mismatch causes alert not being displayed (Sam Batschelet)
- NO-ISSUE: agent/os: only pull if not booted (Sam Batschelet)
- NO-ISSUE: Cleanup remnants from grpc endpoint previously surfaced at 7444 (Dakota Crowder)
- EDM-1186: Updates to quadlets config and rpm spec per feedback (Dakota Crowder)
- EDM-1186: RPM Quadlet Installer initial implementation (Dakota Crowder)
- EDM-1186: Use podman secrets to manage db and kv passwords (Dakota Crowder)
- EDM-1394: Revert "EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update" (#1080) (Assaf Albo)
- NO-ISSUE: Fixed minor issues with helm chart when using gateway API (Ram)
- NO-ISSUE: fix for login validation (amalykhi)
- NO-ISSUE: flightctl login validation test (amalykhi)
- EDM-1305:  Console enhancements (Ori Amizur)
- EDM-1313: agent: ensure update error condition is visible (Sam Batschelet)
- EDM-996: flightctl-agent rpm should create /etc/flightctl/ directory (#1069) (Gregory Shilin)
- EDM-1318: Bug fix removing client cert creation at startup (noga-magen)
- EDM-1320: api: improve compose spec validations (Sam Batschelet)
- NO-ISSUE: agent: improve initial sync timing (Sam Batschelet)
- EDM-889: Separate out auth provider config (Frank A. Zdarsky)
- EDM-889: Revert change in token serialization (Frank A. Zdarsky)
- EDM-889: Omit empty fields (Frank A. Zdarsky)
- NO-ISSUE: Added Note (Siddarth R)
- NO-ISSUE: Define global pull policy and use IfNotPresent (rawagner)
- EDM-1320: applications: improve provider validation (Sam Batschelet)
- EDM-1049: Use Stringer to format version (Frank A. Zdarsky)
- EDM-1049: Show field names when printing JSON and YAML output (Frank A. Zdarsky)
- EDM-1049: Enable use of context global flag (Frank A. Zdarsky)
- EDM-1354: In OCP flightctl-cli-artifacts pod is in CrashLoopBackOff installing with the latest helm chart (rawagner)
- EDM-1352: Building a gitserver as a root user fails (#1058) (Gregory Shilin)
- EDM-1294: Expose CLI Downloads via route and gateway. Create ConsoleCLIDownloads CR. (rawagner)
- EDM-1293: Deploy a pod with CLI tools (#1036) (Gregory Shilin)
- EDM-1329: agent/resource: calculate CPU usage with delta-based sampling (Sam Batschelet)
- EDM-1254: Add user documentation for rollout policies (Ori Amizur)
- EDM-1346: bump x/oauth2 and x/crypto (rawagner)
- EDM-1165: Fix AuthZ middleware. Add tests (rawagner)
- EDM-851: Update DevicesSummary to prevent null return (Siddarth R)
- Revert "EDM 851: Update DevicesSummary OpenAPI spec" (Siddarth R)
- EDM-1317: EDM-1321: api: add missing inline application eval (Sam Batschelet)
- EDM-310: Refactor CA handling (Anton Ivanov)
- NO-ISSUE: Update helm charts with new UI params (rawagner)
- EDM 851: Update DevicesSummary OpenAPI spec (Siddarth R)
- NO-ISSUE: Fix status e2e test (sserafin)
- NO-ISSUE: Anchors are not currently supported for workflows (#1013) (Gregory Shilin)
- EDM-1308: Use chi middleware request IDs (Avishay Traeger)
- EDM-1211: *: implement inline application provider (Sam Batschelet)
- EDM-1211: agent/applications: refactor (Sam Batschelet)
- EDM-1211: api: add application inline provider (Sam Batschelet)
- EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update (#1011) (Assaf Albo)
- EDM-1309: Prevent client from setting ER status (Avishay Traeger)
- EDM-1252:Adding labels (Eldar101)
- EDM-696: Support AAP Gateway OAuth2 (rawagner)
- NO-ISSUE: Make example enrollment request valid (Celia Amador)
- EDM-1214: Perform better validation of CSR and enrollment requests (Anton Ivanov)
- EDM-1251: fix JSONB fields in CompositeSelectorResolver (#995) (Assaf Albo)
- EDM-1138: Upgrade go to RH-supported (and FIPS-compatible) version (#980) (Gregory Shilin)
- EDM-1039: Make CLI code Windows compatible (#951) (Gregory Shilin)
- EDM-1044: Add part 1 of hooks e2e tests and small disconnected adaptations (sserafin)
- NO-ISSUE: fix ppa-build (#985) (Gregory Shilin)
- NO-ISSUE: Update CLI login docs (rawagner)
- EDM-1025: Use ServiceHandler rather than Store in tasks (Avishay Traeger)
- EDM-759: Add provisioning, update image building (Frank A. Zdarsky)
- EDM-1245: Add versioning to Device Simulator (#984) (Gregory Shilin)
- NO-ISSUE: Ensure Git metadata persists correctly in Flightctl API build (#970) (Assaf Albo)
- EDM-1247: Use plural selectors for labels endpoint (#979) (Assaf Albo)
- EDM-1049: Add a global RequestTimeout flag to use in CLI commands (#924) (Gregory Shilin)
- EDM-1241: In disconnected env the token fails to be refreshed (Ori Amizur)
- NO-ISSUE: Add docs for decommissioning (Lily Sturmann)
- NO-ISSUE: Remove escapes, remove experimental (Frank A. Zdarsky)
- EDM-1192: Split transport and service layers (Avishay Traeger)
- EDM-1209: Fix token verification error for OR selectors (#966) (Assaf Albo)
- NO-ISSUE: Fix to disconnected-cluster.md (Eldar101)
- EDM-1213: Use alpine from quay.io (sserafin)
- EDM-1213: Replace e2eregistry docker image with flightctl quay.io copy (sserafin)
- EDM-1208: fix e2e cli tests in ocp and adjust timeout (sserafin)
- EDM-1172: Add disconnected clusters support to e2e test vm (sserafin)
- NO-ISSUE: Use redis from quay.io (rawagner)
- EDM-683: Add API for listing distinct device labels (#939) (Assaf Albo)
- EDM-1202: Fix missing Flightctl API Server version in upstream images (asafbss)
- NO-ISSUE: wrong dependencies in spec (Gregory Shilin)
- EDM-1195: Ensure that release-* branches create containers (#954) (Miguel Angel Ajo Pelayo)
- EDM-1191: docs/managing-devices: add section on pull secrets (Sam Batschelet)
- EDM-1178: API client should refresh expired token (Ori Amizur)
- EDM-1191: agent: ensure OS image pull uses ostree path (Sam Batschelet)
- EDM-1181: Update nameOrAlias selector in E2E test (amalykhi)
- NO-ISSUE: copying example yamls to test directory for testing purpose (amalykhi)
- EDM-1076: Improve docs for installing fctl on disconnected env (rawagner)
- EDM-1034: agent/hooks: add support for passing variables to hooks from inline cfg (Sam Batschelet)
- EDM-960: Validations of inline config (amalykhi)
- EDM-1181: ensure camelCase consistency in selector names (#936) (Assaf Albo)
- EDM-1048: api/validation: always validate image (Sam Batschelet)
- EDM-1047: api/validation: ensure whitespace is not valid for application name (Sam Batschelet)
- EDM-1049: CLI installed from RPM (COPR repo) and binary (GH) show the wrong version info (#925) (Gregory Shilin)
- NO-ISSUE: Update docs to refer to stable COPR repo (Frank A. Zdarsky)
- NO-ISSUE: Ensure that tags are treated as strings (rawagner)
- EDM-1176: Do not use images with floating tags (rawagner)
- EDM-1045: Adding E2E tests for finalizing parametrisable device templates (sserafin)
- EDM-1174: Use Authorization header instead of Authentication to align with HTTP spec (#918) (Rastislav Wagner)
- EDM-1168: Make --rendered flag return the full device (Frank A. Zdarsky)
- EDM-1160: docs: update stale references (Sam Batschelet)
- EDM-1160: api/vaidation: ensure consoles can not be added directly to device (Sam Batschelet)
- EDM-1160: *: react to api changes (Sam Batschelet)
- EDM-1160: api: add versioning to agent (Sam Batschelet)
- NO-ISSUE: Remove tar before re-creating it (#903) (Gregory Shilin)
- EDM-1112: pods pull from quay.io in disconnected env (#904) (Gregory Shilin)
- NO-ISSUE: Add API group to docs yamls (Avishay Traeger)
- NO-ISSUE: keep agent config naming consistent in getting started guide (Nick Cao)
- NO-ISSUE: Various user doc fixes (Frank A. Zdarsky)
- Update getting-started.md with Hyperlinks (Florian Moss)

* Thu May 1 2025 Lily Sturmann <lkatalin@users.noreply.github.com> - 0.6.0~main~203~g5db715f9-1.20250501155513097176.tpm.client.may.1.203.g5db715f9
- aseklj (Lily Sturmann)
- asej (Lily Sturmann)
- 29slky (Lily Sturmann)
- 29slkj (Lily Sturmann)
- skj (Lily Sturmann)
- fooo (Lily Sturmann)
- foooo (Lily Sturmann)
- d (Lily Sturmann)
- c (Lily Sturmann)
- b (Lily Sturmann)
- a (Lily Sturmann)
- fooO (Lily Sturmann)
- fooo (Lily Sturmann)
- foo (Lily Sturmann)
- bug fix wip 2 (Lily Sturmann)
- bug fix wip (Lily Sturmann)
- fake commit for systemd change (Lily Sturmann)
- EDM-1016: Add experimental feature to register TPM collection functions (Lily Sturmann)
- EDM-1016: Add TPM client agent-side (Lily Sturmann)
- EDM-1016: Fix for TPM system path (Lily Sturmann)
- EDM-1016: Include collector function data in system info (Lily Sturmann)
- NO-ISSUE: Remove --previous from kubectl log collection (Avishay Traeger)
- EDM-1315: Add events to create/update/delete APIs (Avishay Traeger)
- EDM-1275: Event retention (Avishay Traeger)
- EDM-1276: Add event listing to CLI (Avishay Traeger)
- NO-ISSUE: Fix selector resolving (Avishay Traeger)
- EDM-1274: Store system events in the database (Avishay Traeger)
- EDM-1276: Implement API to retrieve events (Avishay Traeger)
- EDM-1337: Modify nginx config to use only tls 1.3 (Dakota Crowder)
- EDM-1337: Change Warning err messages to Error (Dakota Crowder)
- EDM-1337: Modify rpm spec for install (Dakota Crowder)
- EDM-1337: Adjust setup to use default user for cli container (Dakota Crowder)
- EDM-1337: Install a flightctl-cli-artifacts quadlet (Dakota Crowder)
- EDM-1061: Add function to get TPM vendor info (Lily Sturmann)
- EDM-1435: agent/systemInfo: refactor and implement api (Sam Batschelet)
- EDM-1436: api: extend systemInfo status (Sam Batschelet)
- EDM-837: Document builds with RHEL base image (Frank A. Zdarsky)
- NO-ISSUE: Wrong code is generated for python (Gregory Shilin)
- EDM-1016: Add TPM functionality and unit tests to support attestation (Lily Sturmann)
- NO-ISSUE: Fixing Lint (Siddarth R)
- NO-ISSUE: Add ARM support for CPUInfo (Siddarth R)
- EDM-1333: refactoring to tests (Eldar Weiss)
- EDM-1453: agent: improve transient error handling (Sam Batschelet)
- EDM-1428: Add reload support for configuration changes (Ori Amizur)
- EDM-1452: Fix reference to ensure websocket handler is configured with middleware (Dakota Crowder)
- JIRA-1450:Incorrect Endpoint Used for CSR Approval (Siddarth Royapally)
- EDM-1429: agent: react to changes (Sam Batschelet)
- EDM-1429: agent: add systeminfo manager (Sam Batschelet)
- EDM-1429: agent: add system-info subcommand (Sam Batschelet)
- NO-ISSUE: Use printf rather than echo -e (Dakota Crowder)
- NO-ISSUE: Fix newline run-on issue with no bootc agent container (Dakota Crowder)
- Revert "EDM-1374: Resource monitorType casing mismatch causes alert not being displayed" (Sam Batschelet)
- EDM-1184: changed SELinux policy to allow systemd to start the service (Mario Parra)
- EDM-1367: Create aap oauth app from auth token (Dakota Crowder)
- NO-ISSUE: gRPC streams connections are disconnected after 5 minutes (Ori Amizur)
- EDM-1414: Add patch support for DeviceStatus (Sam Batschelet)
- NO-ISSUE: Revert removal o tags by https://github.com/flightctl/flightctl/pull/1013/ (#1088) (Gregory Shilin)
- EDM-1413: Break out get_services_for_tag function (Dakota Crowder)
- EDM-1413: Address image ref diff for ui images in dev builds (Dakota Crowder)
- EDM-1413: Add comment for ~ replacement context (Dakota Crowder)
- EDM-1413: Set image tag for installed quadlets based off of rpm version (Dakota Crowder)
- EDM-1314: docs: add inline compose details (Sam Batschelet)
- EDM-1295: Configuration for cli artifacts in UI standalone deployment (Celia Amador)
- EDM-1370: Add comment to .target explaining what the Requires and After diretives mean wrt startup ordering (Dakota Crowder)
- EDM-1288: Create sos report plugin for flightctl (Ori Amizur)
- EDM-1370: Remove redundant Wants from target (Dakota Crowder)
- EDM-1370: Run daemon-reload in post install (Dakota Crowder)
- EDM-1370: Improve service dependency mappings and use a .target instead of slice (Dakota Crowder)
- EDM-1333: adding coverage for more steps (Eldar Weiss)
- EDM-1374: Resource monitorType casing mismatch causes alert not being displayed (Sam Batschelet)
- NO-ISSUE: agent/os: only pull if not booted (Sam Batschelet)
- NO-ISSUE: Cleanup remnants from grpc endpoint previously surfaced at 7444 (Dakota Crowder)
- EDM-1186: Updates to quadlets config and rpm spec per feedback (Dakota Crowder)
- EDM-1186: RPM Quadlet Installer initial implementation (Dakota Crowder)
- EDM-1186: Use podman secrets to manage db and kv passwords (Dakota Crowder)
- EDM-1394: Revert "EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update" (#1080) (Assaf Albo)
- NO-ISSUE: Fixed minor issues with helm chart when using gateway API (Ram)
- NO-ISSUE: fix for login validation (amalykhi)
- NO-ISSUE: flightctl login validation test (amalykhi)
- EDM-1305:  Console enhancements (Ori Amizur)
- EDM-1313: agent: ensure update error condition is visible (Sam Batschelet)
- EDM-996: flightctl-agent rpm should create /etc/flightctl/ directory (#1069) (Gregory Shilin)
- EDM-1318: Bug fix removing client cert creation at startup (noga-magen)
- EDM-1320: api: improve compose spec validations (Sam Batschelet)
- NO-ISSUE: agent: improve initial sync timing (Sam Batschelet)
- EDM-889: Separate out auth provider config (Frank A. Zdarsky)
- EDM-889: Revert change in token serialization (Frank A. Zdarsky)
- EDM-889: Omit empty fields (Frank A. Zdarsky)
- NO-ISSUE: Added Note (Siddarth R)
- NO-ISSUE: Define global pull policy and use IfNotPresent (rawagner)
- EDM-1320: applications: improve provider validation (Sam Batschelet)
- EDM-1049: Use Stringer to format version (Frank A. Zdarsky)
- EDM-1049: Show field names when printing JSON and YAML output (Frank A. Zdarsky)
- EDM-1049: Enable use of context global flag (Frank A. Zdarsky)
- EDM-1354: In OCP flightctl-cli-artifacts pod is in CrashLoopBackOff installing with the latest helm chart (rawagner)
- EDM-1352: Building a gitserver as a root user fails (#1058) (Gregory Shilin)
- EDM-1294: Expose CLI Downloads via route and gateway. Create ConsoleCLIDownloads CR. (rawagner)
- EDM-1293: Deploy a pod with CLI tools (#1036) (Gregory Shilin)
- EDM-1329: agent/resource: calculate CPU usage with delta-based sampling (Sam Batschelet)
- EDM-1254: Add user documentation for rollout policies (Ori Amizur)
- EDM-1346: bump x/oauth2 and x/crypto (rawagner)
- EDM-1165: Fix AuthZ middleware. Add tests (rawagner)
- EDM-851: Update DevicesSummary to prevent null return (Siddarth R)
- Revert "EDM 851: Update DevicesSummary OpenAPI spec" (Siddarth R)
- EDM-1317: EDM-1321: api: add missing inline application eval (Sam Batschelet)
- EDM-310: Refactor CA handling (Anton Ivanov)
- NO-ISSUE: Update helm charts with new UI params (rawagner)
- EDM 851: Update DevicesSummary OpenAPI spec (Siddarth R)
- NO-ISSUE: Fix status e2e test (sserafin)
- NO-ISSUE: Anchors are not currently supported for workflows (#1013) (Gregory Shilin)
- EDM-1308: Use chi middleware request IDs (Avishay Traeger)
- EDM-1211: *: implement inline application provider (Sam Batschelet)
- EDM-1211: agent/applications: refactor (Sam Batschelet)
- EDM-1211: api: add application inline provider (Sam Batschelet)
- EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update (#1011) (Assaf Albo)
- EDM-1309: Prevent client from setting ER status (Avishay Traeger)
- EDM-1252:Adding labels (Eldar101)
- EDM-696: Support AAP Gateway OAuth2 (rawagner)
- NO-ISSUE: Make example enrollment request valid (Celia Amador)
- EDM-1214: Perform better validation of CSR and enrollment requests (Anton Ivanov)
- EDM-1251: fix JSONB fields in CompositeSelectorResolver (#995) (Assaf Albo)
- EDM-1138: Upgrade go to RH-supported (and FIPS-compatible) version (#980) (Gregory Shilin)
- EDM-1039: Make CLI code Windows compatible (#951) (Gregory Shilin)
- EDM-1044: Add part 1 of hooks e2e tests and small disconnected adaptations (sserafin)
- NO-ISSUE: fix ppa-build (#985) (Gregory Shilin)
- NO-ISSUE: Update CLI login docs (rawagner)
- EDM-1025: Use ServiceHandler rather than Store in tasks (Avishay Traeger)
- EDM-759: Add provisioning, update image building (Frank A. Zdarsky)
- EDM-1245: Add versioning to Device Simulator (#984) (Gregory Shilin)
- NO-ISSUE: Ensure Git metadata persists correctly in Flightctl API build (#970) (Assaf Albo)
- EDM-1247: Use plural selectors for labels endpoint (#979) (Assaf Albo)
- EDM-1049: Add a global RequestTimeout flag to use in CLI commands (#924) (Gregory Shilin)
- EDM-1241: In disconnected env the token fails to be refreshed (Ori Amizur)
- NO-ISSUE: Add docs for decommissioning (Lily Sturmann)
- NO-ISSUE: Remove escapes, remove experimental (Frank A. Zdarsky)
- EDM-1192: Split transport and service layers (Avishay Traeger)
- EDM-1209: Fix token verification error for OR selectors (#966) (Assaf Albo)
- NO-ISSUE: Fix to disconnected-cluster.md (Eldar101)
- EDM-1213: Use alpine from quay.io (sserafin)
- EDM-1213: Replace e2eregistry docker image with flightctl quay.io copy (sserafin)
- EDM-1208: fix e2e cli tests in ocp and adjust timeout (sserafin)
- EDM-1172: Add disconnected clusters support to e2e test vm (sserafin)
- NO-ISSUE: Use redis from quay.io (rawagner)
- EDM-683: Add API for listing distinct device labels (#939) (Assaf Albo)
- EDM-1202: Fix missing Flightctl API Server version in upstream images (asafbss)
- NO-ISSUE: wrong dependencies in spec (Gregory Shilin)
- EDM-1195: Ensure that release-* branches create containers (#954) (Miguel Angel Ajo Pelayo)
- EDM-1191: docs/managing-devices: add section on pull secrets (Sam Batschelet)
- EDM-1178: API client should refresh expired token (Ori Amizur)
- EDM-1191: agent: ensure OS image pull uses ostree path (Sam Batschelet)
- EDM-1181: Update nameOrAlias selector in E2E test (amalykhi)
- NO-ISSUE: copying example yamls to test directory for testing purpose (amalykhi)
- EDM-1076: Improve docs for installing fctl on disconnected env (rawagner)
- EDM-1034: agent/hooks: add support for passing variables to hooks from inline cfg (Sam Batschelet)
- EDM-960: Validations of inline config (amalykhi)
- EDM-1181: ensure camelCase consistency in selector names (#936) (Assaf Albo)
- EDM-1048: api/validation: always validate image (Sam Batschelet)
- EDM-1047: api/validation: ensure whitespace is not valid for application name (Sam Batschelet)
- EDM-1049: CLI installed from RPM (COPR repo) and binary (GH) show the wrong version info (#925) (Gregory Shilin)
- NO-ISSUE: Update docs to refer to stable COPR repo (Frank A. Zdarsky)
- NO-ISSUE: Ensure that tags are treated as strings (rawagner)
- EDM-1176: Do not use images with floating tags (rawagner)
- EDM-1045: Adding E2E tests for finalizing parametrisable device templates (sserafin)
- EDM-1174: Use Authorization header instead of Authentication to align with HTTP spec (#918) (Rastislav Wagner)
- EDM-1168: Make --rendered flag return the full device (Frank A. Zdarsky)
- EDM-1160: docs: update stale references (Sam Batschelet)
- EDM-1160: api/vaidation: ensure consoles can not be added directly to device (Sam Batschelet)
- EDM-1160: *: react to api changes (Sam Batschelet)
- EDM-1160: api: add versioning to agent (Sam Batschelet)
- NO-ISSUE: Remove tar before re-creating it (#903) (Gregory Shilin)
- EDM-1112: pods pull from quay.io in disconnected env (#904) (Gregory Shilin)
- NO-ISSUE: Add API group to docs yamls (Avishay Traeger)
- NO-ISSUE: keep agent config naming consistent in getting started guide (Nick Cao)
- NO-ISSUE: Various user doc fixes (Frank A. Zdarsky)
- Update getting-started.md with Hyperlinks (Florian Moss)

* Thu May 1 2025 Lily Sturmann <lkatalin@users.noreply.github.com> - 0.6.0~main~200~g0c0d200e-1.20250501153743005084.tpm.client.may.1.200.g0c0d200e
- 29slkj (Lily Sturmann)
- skj (Lily Sturmann)
- fooo (Lily Sturmann)
- foooo (Lily Sturmann)
- d (Lily Sturmann)
- c (Lily Sturmann)
- b (Lily Sturmann)
- a (Lily Sturmann)
- fooO (Lily Sturmann)
- fooo (Lily Sturmann)
- foo (Lily Sturmann)
- bug fix wip 2 (Lily Sturmann)
- bug fix wip (Lily Sturmann)
- fake commit for systemd change (Lily Sturmann)
- EDM-1016: Add experimental feature to register TPM collection functions (Lily Sturmann)
- EDM-1016: Add TPM client agent-side (Lily Sturmann)
- EDM-1016: Fix for TPM system path (Lily Sturmann)
- EDM-1016: Include collector function data in system info (Lily Sturmann)
- NO-ISSUE: Remove --previous from kubectl log collection (Avishay Traeger)
- EDM-1315: Add events to create/update/delete APIs (Avishay Traeger)
- EDM-1275: Event retention (Avishay Traeger)
- EDM-1276: Add event listing to CLI (Avishay Traeger)
- NO-ISSUE: Fix selector resolving (Avishay Traeger)
- EDM-1274: Store system events in the database (Avishay Traeger)
- EDM-1276: Implement API to retrieve events (Avishay Traeger)
- EDM-1337: Modify nginx config to use only tls 1.3 (Dakota Crowder)
- EDM-1337: Change Warning err messages to Error (Dakota Crowder)
- EDM-1337: Modify rpm spec for install (Dakota Crowder)
- EDM-1337: Adjust setup to use default user for cli container (Dakota Crowder)
- EDM-1337: Install a flightctl-cli-artifacts quadlet (Dakota Crowder)
- EDM-1061: Add function to get TPM vendor info (Lily Sturmann)
- EDM-1435: agent/systemInfo: refactor and implement api (Sam Batschelet)
- EDM-1436: api: extend systemInfo status (Sam Batschelet)
- EDM-837: Document builds with RHEL base image (Frank A. Zdarsky)
- NO-ISSUE: Wrong code is generated for python (Gregory Shilin)
- EDM-1016: Add TPM functionality and unit tests to support attestation (Lily Sturmann)
- NO-ISSUE: Fixing Lint (Siddarth R)
- NO-ISSUE: Add ARM support for CPUInfo (Siddarth R)
- EDM-1333: refactoring to tests (Eldar Weiss)
- EDM-1453: agent: improve transient error handling (Sam Batschelet)
- EDM-1428: Add reload support for configuration changes (Ori Amizur)
- EDM-1452: Fix reference to ensure websocket handler is configured with middleware (Dakota Crowder)
- JIRA-1450:Incorrect Endpoint Used for CSR Approval (Siddarth Royapally)
- EDM-1429: agent: react to changes (Sam Batschelet)
- EDM-1429: agent: add systeminfo manager (Sam Batschelet)
- EDM-1429: agent: add system-info subcommand (Sam Batschelet)
- NO-ISSUE: Use printf rather than echo -e (Dakota Crowder)
- NO-ISSUE: Fix newline run-on issue with no bootc agent container (Dakota Crowder)
- Revert "EDM-1374: Resource monitorType casing mismatch causes alert not being displayed" (Sam Batschelet)
- EDM-1184: changed SELinux policy to allow systemd to start the service (Mario Parra)
- EDM-1367: Create aap oauth app from auth token (Dakota Crowder)
- NO-ISSUE: gRPC streams connections are disconnected after 5 minutes (Ori Amizur)
- EDM-1414: Add patch support for DeviceStatus (Sam Batschelet)
- NO-ISSUE: Revert removal o tags by https://github.com/flightctl/flightctl/pull/1013/ (#1088) (Gregory Shilin)
- EDM-1413: Break out get_services_for_tag function (Dakota Crowder)
- EDM-1413: Address image ref diff for ui images in dev builds (Dakota Crowder)
- EDM-1413: Add comment for ~ replacement context (Dakota Crowder)
- EDM-1413: Set image tag for installed quadlets based off of rpm version (Dakota Crowder)
- EDM-1314: docs: add inline compose details (Sam Batschelet)
- EDM-1295: Configuration for cli artifacts in UI standalone deployment (Celia Amador)
- EDM-1370: Add comment to .target explaining what the Requires and After diretives mean wrt startup ordering (Dakota Crowder)
- EDM-1288: Create sos report plugin for flightctl (Ori Amizur)
- EDM-1370: Remove redundant Wants from target (Dakota Crowder)
- EDM-1370: Run daemon-reload in post install (Dakota Crowder)
- EDM-1370: Improve service dependency mappings and use a .target instead of slice (Dakota Crowder)
- EDM-1333: adding coverage for more steps (Eldar Weiss)
- EDM-1374: Resource monitorType casing mismatch causes alert not being displayed (Sam Batschelet)
- NO-ISSUE: agent/os: only pull if not booted (Sam Batschelet)
- NO-ISSUE: Cleanup remnants from grpc endpoint previously surfaced at 7444 (Dakota Crowder)
- EDM-1186: Updates to quadlets config and rpm spec per feedback (Dakota Crowder)
- EDM-1186: RPM Quadlet Installer initial implementation (Dakota Crowder)
- EDM-1186: Use podman secrets to manage db and kv passwords (Dakota Crowder)
- EDM-1394: Revert "EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update" (#1080) (Assaf Albo)
- NO-ISSUE: Fixed minor issues with helm chart when using gateway API (Ram)
- NO-ISSUE: fix for login validation (amalykhi)
- NO-ISSUE: flightctl login validation test (amalykhi)
- EDM-1305:  Console enhancements (Ori Amizur)
- EDM-1313: agent: ensure update error condition is visible (Sam Batschelet)
- EDM-996: flightctl-agent rpm should create /etc/flightctl/ directory (#1069) (Gregory Shilin)
- EDM-1318: Bug fix removing client cert creation at startup (noga-magen)
- EDM-1320: api: improve compose spec validations (Sam Batschelet)
- NO-ISSUE: agent: improve initial sync timing (Sam Batschelet)
- EDM-889: Separate out auth provider config (Frank A. Zdarsky)
- EDM-889: Revert change in token serialization (Frank A. Zdarsky)
- EDM-889: Omit empty fields (Frank A. Zdarsky)
- NO-ISSUE: Added Note (Siddarth R)
- NO-ISSUE: Define global pull policy and use IfNotPresent (rawagner)
- EDM-1320: applications: improve provider validation (Sam Batschelet)
- EDM-1049: Use Stringer to format version (Frank A. Zdarsky)
- EDM-1049: Show field names when printing JSON and YAML output (Frank A. Zdarsky)
- EDM-1049: Enable use of context global flag (Frank A. Zdarsky)
- EDM-1354: In OCP flightctl-cli-artifacts pod is in CrashLoopBackOff installing with the latest helm chart (rawagner)
- EDM-1352: Building a gitserver as a root user fails (#1058) (Gregory Shilin)
- EDM-1294: Expose CLI Downloads via route and gateway. Create ConsoleCLIDownloads CR. (rawagner)
- EDM-1293: Deploy a pod with CLI tools (#1036) (Gregory Shilin)
- EDM-1329: agent/resource: calculate CPU usage with delta-based sampling (Sam Batschelet)
- EDM-1254: Add user documentation for rollout policies (Ori Amizur)
- EDM-1346: bump x/oauth2 and x/crypto (rawagner)
- EDM-1165: Fix AuthZ middleware. Add tests (rawagner)
- EDM-851: Update DevicesSummary to prevent null return (Siddarth R)
- Revert "EDM 851: Update DevicesSummary OpenAPI spec" (Siddarth R)
- EDM-1317: EDM-1321: api: add missing inline application eval (Sam Batschelet)
- EDM-310: Refactor CA handling (Anton Ivanov)
- NO-ISSUE: Update helm charts with new UI params (rawagner)
- EDM 851: Update DevicesSummary OpenAPI spec (Siddarth R)
- NO-ISSUE: Fix status e2e test (sserafin)
- NO-ISSUE: Anchors are not currently supported for workflows (#1013) (Gregory Shilin)
- EDM-1308: Use chi middleware request IDs (Avishay Traeger)
- EDM-1211: *: implement inline application provider (Sam Batschelet)
- EDM-1211: agent/applications: refactor (Sam Batschelet)
- EDM-1211: api: add application inline provider (Sam Batschelet)
- EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update (#1011) (Assaf Albo)
- EDM-1309: Prevent client from setting ER status (Avishay Traeger)
- EDM-1252:Adding labels (Eldar101)
- EDM-696: Support AAP Gateway OAuth2 (rawagner)
- NO-ISSUE: Make example enrollment request valid (Celia Amador)
- EDM-1214: Perform better validation of CSR and enrollment requests (Anton Ivanov)
- EDM-1251: fix JSONB fields in CompositeSelectorResolver (#995) (Assaf Albo)
- EDM-1138: Upgrade go to RH-supported (and FIPS-compatible) version (#980) (Gregory Shilin)
- EDM-1039: Make CLI code Windows compatible (#951) (Gregory Shilin)
- EDM-1044: Add part 1 of hooks e2e tests and small disconnected adaptations (sserafin)
- NO-ISSUE: fix ppa-build (#985) (Gregory Shilin)
- NO-ISSUE: Update CLI login docs (rawagner)
- EDM-1025: Use ServiceHandler rather than Store in tasks (Avishay Traeger)
- EDM-759: Add provisioning, update image building (Frank A. Zdarsky)
- EDM-1245: Add versioning to Device Simulator (#984) (Gregory Shilin)
- NO-ISSUE: Ensure Git metadata persists correctly in Flightctl API build (#970) (Assaf Albo)
- EDM-1247: Use plural selectors for labels endpoint (#979) (Assaf Albo)
- EDM-1049: Add a global RequestTimeout flag to use in CLI commands (#924) (Gregory Shilin)
- EDM-1241: In disconnected env the token fails to be refreshed (Ori Amizur)
- NO-ISSUE: Add docs for decommissioning (Lily Sturmann)
- NO-ISSUE: Remove escapes, remove experimental (Frank A. Zdarsky)
- EDM-1192: Split transport and service layers (Avishay Traeger)
- EDM-1209: Fix token verification error for OR selectors (#966) (Assaf Albo)
- NO-ISSUE: Fix to disconnected-cluster.md (Eldar101)
- EDM-1213: Use alpine from quay.io (sserafin)
- EDM-1213: Replace e2eregistry docker image with flightctl quay.io copy (sserafin)
- EDM-1208: fix e2e cli tests in ocp and adjust timeout (sserafin)
- EDM-1172: Add disconnected clusters support to e2e test vm (sserafin)
- NO-ISSUE: Use redis from quay.io (rawagner)
- EDM-683: Add API for listing distinct device labels (#939) (Assaf Albo)
- EDM-1202: Fix missing Flightctl API Server version in upstream images (asafbss)
- NO-ISSUE: wrong dependencies in spec (Gregory Shilin)
- EDM-1195: Ensure that release-* branches create containers (#954) (Miguel Angel Ajo Pelayo)
- EDM-1191: docs/managing-devices: add section on pull secrets (Sam Batschelet)
- EDM-1178: API client should refresh expired token (Ori Amizur)
- EDM-1191: agent: ensure OS image pull uses ostree path (Sam Batschelet)
- EDM-1181: Update nameOrAlias selector in E2E test (amalykhi)
- NO-ISSUE: copying example yamls to test directory for testing purpose (amalykhi)
- EDM-1076: Improve docs for installing fctl on disconnected env (rawagner)
- EDM-1034: agent/hooks: add support for passing variables to hooks from inline cfg (Sam Batschelet)
- EDM-960: Validations of inline config (amalykhi)
- EDM-1181: ensure camelCase consistency in selector names (#936) (Assaf Albo)
- EDM-1048: api/validation: always validate image (Sam Batschelet)
- EDM-1047: api/validation: ensure whitespace is not valid for application name (Sam Batschelet)
- EDM-1049: CLI installed from RPM (COPR repo) and binary (GH) show the wrong version info (#925) (Gregory Shilin)
- NO-ISSUE: Update docs to refer to stable COPR repo (Frank A. Zdarsky)
- NO-ISSUE: Ensure that tags are treated as strings (rawagner)
- EDM-1176: Do not use images with floating tags (rawagner)
- EDM-1045: Adding E2E tests for finalizing parametrisable device templates (sserafin)
- EDM-1174: Use Authorization header instead of Authentication to align with HTTP spec (#918) (Rastislav Wagner)
- EDM-1168: Make --rendered flag return the full device (Frank A. Zdarsky)
- EDM-1160: docs: update stale references (Sam Batschelet)
- EDM-1160: api/vaidation: ensure consoles can not be added directly to device (Sam Batschelet)
- EDM-1160: *: react to api changes (Sam Batschelet)
- EDM-1160: api: add versioning to agent (Sam Batschelet)
- NO-ISSUE: Remove tar before re-creating it (#903) (Gregory Shilin)
- EDM-1112: pods pull from quay.io in disconnected env (#904) (Gregory Shilin)
- NO-ISSUE: Add API group to docs yamls (Avishay Traeger)
- NO-ISSUE: keep agent config naming consistent in getting started guide (Nick Cao)
- NO-ISSUE: Various user doc fixes (Frank A. Zdarsky)
- Update getting-started.md with Hyperlinks (Florian Moss)

* Thu May 1 2025 Lily Sturmann <lkatalin@users.noreply.github.com> - 0.6.0~main~196~g84140b04-1.20250501151657113102.tpm.client.may.1.196.g84140b04
- d (Lily Sturmann)
- c (Lily Sturmann)
- b (Lily Sturmann)
- a (Lily Sturmann)
- fooO (Lily Sturmann)
- fooo (Lily Sturmann)
- foo (Lily Sturmann)
- bug fix wip 2 (Lily Sturmann)
- bug fix wip (Lily Sturmann)
- fake commit for systemd change (Lily Sturmann)
- EDM-1016: Add experimental feature to register TPM collection functions (Lily Sturmann)
- EDM-1016: Add TPM client agent-side (Lily Sturmann)
- EDM-1016: Fix for TPM system path (Lily Sturmann)
- EDM-1016: Include collector function data in system info (Lily Sturmann)
- NO-ISSUE: Remove --previous from kubectl log collection (Avishay Traeger)
- EDM-1315: Add events to create/update/delete APIs (Avishay Traeger)
- EDM-1275: Event retention (Avishay Traeger)
- EDM-1276: Add event listing to CLI (Avishay Traeger)
- NO-ISSUE: Fix selector resolving (Avishay Traeger)
- EDM-1274: Store system events in the database (Avishay Traeger)
- EDM-1276: Implement API to retrieve events (Avishay Traeger)
- EDM-1337: Modify nginx config to use only tls 1.3 (Dakota Crowder)
- EDM-1337: Change Warning err messages to Error (Dakota Crowder)
- EDM-1337: Modify rpm spec for install (Dakota Crowder)
- EDM-1337: Adjust setup to use default user for cli container (Dakota Crowder)
- EDM-1337: Install a flightctl-cli-artifacts quadlet (Dakota Crowder)
- EDM-1061: Add function to get TPM vendor info (Lily Sturmann)
- EDM-1435: agent/systemInfo: refactor and implement api (Sam Batschelet)
- EDM-1436: api: extend systemInfo status (Sam Batschelet)
- EDM-837: Document builds with RHEL base image (Frank A. Zdarsky)
- NO-ISSUE: Wrong code is generated for python (Gregory Shilin)
- EDM-1016: Add TPM functionality and unit tests to support attestation (Lily Sturmann)
- NO-ISSUE: Fixing Lint (Siddarth R)
- NO-ISSUE: Add ARM support for CPUInfo (Siddarth R)
- EDM-1333: refactoring to tests (Eldar Weiss)
- EDM-1453: agent: improve transient error handling (Sam Batschelet)
- EDM-1428: Add reload support for configuration changes (Ori Amizur)
- EDM-1452: Fix reference to ensure websocket handler is configured with middleware (Dakota Crowder)
- JIRA-1450:Incorrect Endpoint Used for CSR Approval (Siddarth Royapally)
- EDM-1429: agent: react to changes (Sam Batschelet)
- EDM-1429: agent: add systeminfo manager (Sam Batschelet)
- EDM-1429: agent: add system-info subcommand (Sam Batschelet)
- NO-ISSUE: Use printf rather than echo -e (Dakota Crowder)
- NO-ISSUE: Fix newline run-on issue with no bootc agent container (Dakota Crowder)
- Revert "EDM-1374: Resource monitorType casing mismatch causes alert not being displayed" (Sam Batschelet)
- EDM-1184: changed SELinux policy to allow systemd to start the service (Mario Parra)
- EDM-1367: Create aap oauth app from auth token (Dakota Crowder)
- NO-ISSUE: gRPC streams connections are disconnected after 5 minutes (Ori Amizur)
- EDM-1414: Add patch support for DeviceStatus (Sam Batschelet)
- NO-ISSUE: Revert removal o tags by https://github.com/flightctl/flightctl/pull/1013/ (#1088) (Gregory Shilin)
- EDM-1413: Break out get_services_for_tag function (Dakota Crowder)
- EDM-1413: Address image ref diff for ui images in dev builds (Dakota Crowder)
- EDM-1413: Add comment for ~ replacement context (Dakota Crowder)
- EDM-1413: Set image tag for installed quadlets based off of rpm version (Dakota Crowder)
- EDM-1314: docs: add inline compose details (Sam Batschelet)
- EDM-1295: Configuration for cli artifacts in UI standalone deployment (Celia Amador)
- EDM-1370: Add comment to .target explaining what the Requires and After diretives mean wrt startup ordering (Dakota Crowder)
- EDM-1288: Create sos report plugin for flightctl (Ori Amizur)
- EDM-1370: Remove redundant Wants from target (Dakota Crowder)
- EDM-1370: Run daemon-reload in post install (Dakota Crowder)
- EDM-1370: Improve service dependency mappings and use a .target instead of slice (Dakota Crowder)
- EDM-1333: adding coverage for more steps (Eldar Weiss)
- EDM-1374: Resource monitorType casing mismatch causes alert not being displayed (Sam Batschelet)
- NO-ISSUE: agent/os: only pull if not booted (Sam Batschelet)
- NO-ISSUE: Cleanup remnants from grpc endpoint previously surfaced at 7444 (Dakota Crowder)
- EDM-1186: Updates to quadlets config and rpm spec per feedback (Dakota Crowder)
- EDM-1186: RPM Quadlet Installer initial implementation (Dakota Crowder)
- EDM-1186: Use podman secrets to manage db and kv passwords (Dakota Crowder)
- EDM-1394: Revert "EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update" (#1080) (Assaf Albo)
- NO-ISSUE: Fixed minor issues with helm chart when using gateway API (Ram)
- NO-ISSUE: fix for login validation (amalykhi)
- NO-ISSUE: flightctl login validation test (amalykhi)
- EDM-1305:  Console enhancements (Ori Amizur)
- EDM-1313: agent: ensure update error condition is visible (Sam Batschelet)
- EDM-996: flightctl-agent rpm should create /etc/flightctl/ directory (#1069) (Gregory Shilin)
- EDM-1318: Bug fix removing client cert creation at startup (noga-magen)
- EDM-1320: api: improve compose spec validations (Sam Batschelet)
- NO-ISSUE: agent: improve initial sync timing (Sam Batschelet)
- EDM-889: Separate out auth provider config (Frank A. Zdarsky)
- EDM-889: Revert change in token serialization (Frank A. Zdarsky)
- EDM-889: Omit empty fields (Frank A. Zdarsky)
- NO-ISSUE: Added Note (Siddarth R)
- NO-ISSUE: Define global pull policy and use IfNotPresent (rawagner)
- EDM-1320: applications: improve provider validation (Sam Batschelet)
- EDM-1049: Use Stringer to format version (Frank A. Zdarsky)
- EDM-1049: Show field names when printing JSON and YAML output (Frank A. Zdarsky)
- EDM-1049: Enable use of context global flag (Frank A. Zdarsky)
- EDM-1354: In OCP flightctl-cli-artifacts pod is in CrashLoopBackOff installing with the latest helm chart (rawagner)
- EDM-1352: Building a gitserver as a root user fails (#1058) (Gregory Shilin)
- EDM-1294: Expose CLI Downloads via route and gateway. Create ConsoleCLIDownloads CR. (rawagner)
- EDM-1293: Deploy a pod with CLI tools (#1036) (Gregory Shilin)
- EDM-1329: agent/resource: calculate CPU usage with delta-based sampling (Sam Batschelet)
- EDM-1254: Add user documentation for rollout policies (Ori Amizur)
- EDM-1346: bump x/oauth2 and x/crypto (rawagner)
- EDM-1165: Fix AuthZ middleware. Add tests (rawagner)
- EDM-851: Update DevicesSummary to prevent null return (Siddarth R)
- Revert "EDM 851: Update DevicesSummary OpenAPI spec" (Siddarth R)
- EDM-1317: EDM-1321: api: add missing inline application eval (Sam Batschelet)
- EDM-310: Refactor CA handling (Anton Ivanov)
- NO-ISSUE: Update helm charts with new UI params (rawagner)
- EDM 851: Update DevicesSummary OpenAPI spec (Siddarth R)
- NO-ISSUE: Fix status e2e test (sserafin)
- NO-ISSUE: Anchors are not currently supported for workflows (#1013) (Gregory Shilin)
- EDM-1308: Use chi middleware request IDs (Avishay Traeger)
- EDM-1211: *: implement inline application provider (Sam Batschelet)
- EDM-1211: agent/applications: refactor (Sam Batschelet)
- EDM-1211: api: add application inline provider (Sam Batschelet)
- EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update (#1011) (Assaf Albo)
- EDM-1309: Prevent client from setting ER status (Avishay Traeger)
- EDM-1252:Adding labels (Eldar101)
- EDM-696: Support AAP Gateway OAuth2 (rawagner)
- NO-ISSUE: Make example enrollment request valid (Celia Amador)
- EDM-1214: Perform better validation of CSR and enrollment requests (Anton Ivanov)
- EDM-1251: fix JSONB fields in CompositeSelectorResolver (#995) (Assaf Albo)
- EDM-1138: Upgrade go to RH-supported (and FIPS-compatible) version (#980) (Gregory Shilin)
- EDM-1039: Make CLI code Windows compatible (#951) (Gregory Shilin)
- EDM-1044: Add part 1 of hooks e2e tests and small disconnected adaptations (sserafin)
- NO-ISSUE: fix ppa-build (#985) (Gregory Shilin)
- NO-ISSUE: Update CLI login docs (rawagner)
- EDM-1025: Use ServiceHandler rather than Store in tasks (Avishay Traeger)
- EDM-759: Add provisioning, update image building (Frank A. Zdarsky)
- EDM-1245: Add versioning to Device Simulator (#984) (Gregory Shilin)
- NO-ISSUE: Ensure Git metadata persists correctly in Flightctl API build (#970) (Assaf Albo)
- EDM-1247: Use plural selectors for labels endpoint (#979) (Assaf Albo)
- EDM-1049: Add a global RequestTimeout flag to use in CLI commands (#924) (Gregory Shilin)
- EDM-1241: In disconnected env the token fails to be refreshed (Ori Amizur)
- NO-ISSUE: Add docs for decommissioning (Lily Sturmann)
- NO-ISSUE: Remove escapes, remove experimental (Frank A. Zdarsky)
- EDM-1192: Split transport and service layers (Avishay Traeger)
- EDM-1209: Fix token verification error for OR selectors (#966) (Assaf Albo)
- NO-ISSUE: Fix to disconnected-cluster.md (Eldar101)
- EDM-1213: Use alpine from quay.io (sserafin)
- EDM-1213: Replace e2eregistry docker image with flightctl quay.io copy (sserafin)
- EDM-1208: fix e2e cli tests in ocp and adjust timeout (sserafin)
- EDM-1172: Add disconnected clusters support to e2e test vm (sserafin)
- NO-ISSUE: Use redis from quay.io (rawagner)
- EDM-683: Add API for listing distinct device labels (#939) (Assaf Albo)
- EDM-1202: Fix missing Flightctl API Server version in upstream images (asafbss)
- NO-ISSUE: wrong dependencies in spec (Gregory Shilin)
- EDM-1195: Ensure that release-* branches create containers (#954) (Miguel Angel Ajo Pelayo)
- EDM-1191: docs/managing-devices: add section on pull secrets (Sam Batschelet)
- EDM-1178: API client should refresh expired token (Ori Amizur)
- EDM-1191: agent: ensure OS image pull uses ostree path (Sam Batschelet)
- EDM-1181: Update nameOrAlias selector in E2E test (amalykhi)
- NO-ISSUE: copying example yamls to test directory for testing purpose (amalykhi)
- EDM-1076: Improve docs for installing fctl on disconnected env (rawagner)
- EDM-1034: agent/hooks: add support for passing variables to hooks from inline cfg (Sam Batschelet)
- EDM-960: Validations of inline config (amalykhi)
- EDM-1181: ensure camelCase consistency in selector names (#936) (Assaf Albo)
- EDM-1048: api/validation: always validate image (Sam Batschelet)
- EDM-1047: api/validation: ensure whitespace is not valid for application name (Sam Batschelet)
- EDM-1049: CLI installed from RPM (COPR repo) and binary (GH) show the wrong version info (#925) (Gregory Shilin)
- NO-ISSUE: Update docs to refer to stable COPR repo (Frank A. Zdarsky)
- NO-ISSUE: Ensure that tags are treated as strings (rawagner)
- EDM-1176: Do not use images with floating tags (rawagner)
- EDM-1045: Adding E2E tests for finalizing parametrisable device templates (sserafin)
- EDM-1174: Use Authorization header instead of Authentication to align with HTTP spec (#918) (Rastislav Wagner)
- EDM-1168: Make --rendered flag return the full device (Frank A. Zdarsky)
- EDM-1160: docs: update stale references (Sam Batschelet)
- EDM-1160: api/vaidation: ensure consoles can not be added directly to device (Sam Batschelet)
- EDM-1160: *: react to api changes (Sam Batschelet)
- EDM-1160: api: add versioning to agent (Sam Batschelet)
- NO-ISSUE: Remove tar before re-creating it (#903) (Gregory Shilin)
- EDM-1112: pods pull from quay.io in disconnected env (#904) (Gregory Shilin)
- NO-ISSUE: Add API group to docs yamls (Avishay Traeger)
- NO-ISSUE: keep agent config naming consistent in getting started guide (Nick Cao)
- NO-ISSUE: Various user doc fixes (Frank A. Zdarsky)
- Update getting-started.md with Hyperlinks (Florian Moss)

* Thu May 1 2025 Lily Sturmann <lkatalin@users.noreply.github.com> - 0.6.0~main~196~g84140b04-1.20250501151611669302.tpm.client.may.1.196.g84140b04
- d (Lily Sturmann)
- c (Lily Sturmann)
- b (Lily Sturmann)
- a (Lily Sturmann)
- fooO (Lily Sturmann)
- fooo (Lily Sturmann)
- foo (Lily Sturmann)
- bug fix wip 2 (Lily Sturmann)
- bug fix wip (Lily Sturmann)
- fake commit for systemd change (Lily Sturmann)
- EDM-1016: Add experimental feature to register TPM collection functions (Lily Sturmann)
- EDM-1016: Add TPM client agent-side (Lily Sturmann)
- EDM-1016: Fix for TPM system path (Lily Sturmann)
- EDM-1016: Include collector function data in system info (Lily Sturmann)
- NO-ISSUE: Remove --previous from kubectl log collection (Avishay Traeger)
- EDM-1315: Add events to create/update/delete APIs (Avishay Traeger)
- EDM-1275: Event retention (Avishay Traeger)
- EDM-1276: Add event listing to CLI (Avishay Traeger)
- NO-ISSUE: Fix selector resolving (Avishay Traeger)
- EDM-1274: Store system events in the database (Avishay Traeger)
- EDM-1276: Implement API to retrieve events (Avishay Traeger)
- EDM-1337: Modify nginx config to use only tls 1.3 (Dakota Crowder)
- EDM-1337: Change Warning err messages to Error (Dakota Crowder)
- EDM-1337: Modify rpm spec for install (Dakota Crowder)
- EDM-1337: Adjust setup to use default user for cli container (Dakota Crowder)
- EDM-1337: Install a flightctl-cli-artifacts quadlet (Dakota Crowder)
- EDM-1061: Add function to get TPM vendor info (Lily Sturmann)
- EDM-1435: agent/systemInfo: refactor and implement api (Sam Batschelet)
- EDM-1436: api: extend systemInfo status (Sam Batschelet)
- EDM-837: Document builds with RHEL base image (Frank A. Zdarsky)
- NO-ISSUE: Wrong code is generated for python (Gregory Shilin)
- EDM-1016: Add TPM functionality and unit tests to support attestation (Lily Sturmann)
- NO-ISSUE: Fixing Lint (Siddarth R)
- NO-ISSUE: Add ARM support for CPUInfo (Siddarth R)
- EDM-1333: refactoring to tests (Eldar Weiss)
- EDM-1453: agent: improve transient error handling (Sam Batschelet)
- EDM-1428: Add reload support for configuration changes (Ori Amizur)
- EDM-1452: Fix reference to ensure websocket handler is configured with middleware (Dakota Crowder)
- JIRA-1450:Incorrect Endpoint Used for CSR Approval (Siddarth Royapally)
- EDM-1429: agent: react to changes (Sam Batschelet)
- EDM-1429: agent: add systeminfo manager (Sam Batschelet)
- EDM-1429: agent: add system-info subcommand (Sam Batschelet)
- NO-ISSUE: Use printf rather than echo -e (Dakota Crowder)
- NO-ISSUE: Fix newline run-on issue with no bootc agent container (Dakota Crowder)
- Revert "EDM-1374: Resource monitorType casing mismatch causes alert not being displayed" (Sam Batschelet)
- EDM-1184: changed SELinux policy to allow systemd to start the service (Mario Parra)
- EDM-1367: Create aap oauth app from auth token (Dakota Crowder)
- NO-ISSUE: gRPC streams connections are disconnected after 5 minutes (Ori Amizur)
- EDM-1414: Add patch support for DeviceStatus (Sam Batschelet)
- NO-ISSUE: Revert removal o tags by https://github.com/flightctl/flightctl/pull/1013/ (#1088) (Gregory Shilin)
- EDM-1413: Break out get_services_for_tag function (Dakota Crowder)
- EDM-1413: Address image ref diff for ui images in dev builds (Dakota Crowder)
- EDM-1413: Add comment for ~ replacement context (Dakota Crowder)
- EDM-1413: Set image tag for installed quadlets based off of rpm version (Dakota Crowder)
- EDM-1314: docs: add inline compose details (Sam Batschelet)
- EDM-1295: Configuration for cli artifacts in UI standalone deployment (Celia Amador)
- EDM-1370: Add comment to .target explaining what the Requires and After diretives mean wrt startup ordering (Dakota Crowder)
- EDM-1288: Create sos report plugin for flightctl (Ori Amizur)
- EDM-1370: Remove redundant Wants from target (Dakota Crowder)
- EDM-1370: Run daemon-reload in post install (Dakota Crowder)
- EDM-1370: Improve service dependency mappings and use a .target instead of slice (Dakota Crowder)
- EDM-1333: adding coverage for more steps (Eldar Weiss)
- EDM-1374: Resource monitorType casing mismatch causes alert not being displayed (Sam Batschelet)
- NO-ISSUE: agent/os: only pull if not booted (Sam Batschelet)
- NO-ISSUE: Cleanup remnants from grpc endpoint previously surfaced at 7444 (Dakota Crowder)
- EDM-1186: Updates to quadlets config and rpm spec per feedback (Dakota Crowder)
- EDM-1186: RPM Quadlet Installer initial implementation (Dakota Crowder)
- EDM-1186: Use podman secrets to manage db and kv passwords (Dakota Crowder)
- EDM-1394: Revert "EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update" (#1080) (Assaf Albo)
- NO-ISSUE: Fixed minor issues with helm chart when using gateway API (Ram)
- NO-ISSUE: fix for login validation (amalykhi)
- NO-ISSUE: flightctl login validation test (amalykhi)
- EDM-1305:  Console enhancements (Ori Amizur)
- EDM-1313: agent: ensure update error condition is visible (Sam Batschelet)
- EDM-996: flightctl-agent rpm should create /etc/flightctl/ directory (#1069) (Gregory Shilin)
- EDM-1318: Bug fix removing client cert creation at startup (noga-magen)
- EDM-1320: api: improve compose spec validations (Sam Batschelet)
- NO-ISSUE: agent: improve initial sync timing (Sam Batschelet)
- EDM-889: Separate out auth provider config (Frank A. Zdarsky)
- EDM-889: Revert change in token serialization (Frank A. Zdarsky)
- EDM-889: Omit empty fields (Frank A. Zdarsky)
- NO-ISSUE: Added Note (Siddarth R)
- NO-ISSUE: Define global pull policy and use IfNotPresent (rawagner)
- EDM-1320: applications: improve provider validation (Sam Batschelet)
- EDM-1049: Use Stringer to format version (Frank A. Zdarsky)
- EDM-1049: Show field names when printing JSON and YAML output (Frank A. Zdarsky)
- EDM-1049: Enable use of context global flag (Frank A. Zdarsky)
- EDM-1354: In OCP flightctl-cli-artifacts pod is in CrashLoopBackOff installing with the latest helm chart (rawagner)
- EDM-1352: Building a gitserver as a root user fails (#1058) (Gregory Shilin)
- EDM-1294: Expose CLI Downloads via route and gateway. Create ConsoleCLIDownloads CR. (rawagner)
- EDM-1293: Deploy a pod with CLI tools (#1036) (Gregory Shilin)
- EDM-1329: agent/resource: calculate CPU usage with delta-based sampling (Sam Batschelet)
- EDM-1254: Add user documentation for rollout policies (Ori Amizur)
- EDM-1346: bump x/oauth2 and x/crypto (rawagner)
- EDM-1165: Fix AuthZ middleware. Add tests (rawagner)
- EDM-851: Update DevicesSummary to prevent null return (Siddarth R)
- Revert "EDM 851: Update DevicesSummary OpenAPI spec" (Siddarth R)
- EDM-1317: EDM-1321: api: add missing inline application eval (Sam Batschelet)
- EDM-310: Refactor CA handling (Anton Ivanov)
- NO-ISSUE: Update helm charts with new UI params (rawagner)
- EDM 851: Update DevicesSummary OpenAPI spec (Siddarth R)
- NO-ISSUE: Fix status e2e test (sserafin)
- NO-ISSUE: Anchors are not currently supported for workflows (#1013) (Gregory Shilin)
- EDM-1308: Use chi middleware request IDs (Avishay Traeger)
- EDM-1211: *: implement inline application provider (Sam Batschelet)
- EDM-1211: agent/applications: refactor (Sam Batschelet)
- EDM-1211: api: add application inline provider (Sam Batschelet)
- EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update (#1011) (Assaf Albo)
- EDM-1309: Prevent client from setting ER status (Avishay Traeger)
- EDM-1252:Adding labels (Eldar101)
- EDM-696: Support AAP Gateway OAuth2 (rawagner)
- NO-ISSUE: Make example enrollment request valid (Celia Amador)
- EDM-1214: Perform better validation of CSR and enrollment requests (Anton Ivanov)
- EDM-1251: fix JSONB fields in CompositeSelectorResolver (#995) (Assaf Albo)
- EDM-1138: Upgrade go to RH-supported (and FIPS-compatible) version (#980) (Gregory Shilin)
- EDM-1039: Make CLI code Windows compatible (#951) (Gregory Shilin)
- EDM-1044: Add part 1 of hooks e2e tests and small disconnected adaptations (sserafin)
- NO-ISSUE: fix ppa-build (#985) (Gregory Shilin)
- NO-ISSUE: Update CLI login docs (rawagner)
- EDM-1025: Use ServiceHandler rather than Store in tasks (Avishay Traeger)
- EDM-759: Add provisioning, update image building (Frank A. Zdarsky)
- EDM-1245: Add versioning to Device Simulator (#984) (Gregory Shilin)
- NO-ISSUE: Ensure Git metadata persists correctly in Flightctl API build (#970) (Assaf Albo)
- EDM-1247: Use plural selectors for labels endpoint (#979) (Assaf Albo)
- EDM-1049: Add a global RequestTimeout flag to use in CLI commands (#924) (Gregory Shilin)
- EDM-1241: In disconnected env the token fails to be refreshed (Ori Amizur)
- NO-ISSUE: Add docs for decommissioning (Lily Sturmann)
- NO-ISSUE: Remove escapes, remove experimental (Frank A. Zdarsky)
- EDM-1192: Split transport and service layers (Avishay Traeger)
- EDM-1209: Fix token verification error for OR selectors (#966) (Assaf Albo)
- NO-ISSUE: Fix to disconnected-cluster.md (Eldar101)
- EDM-1213: Use alpine from quay.io (sserafin)
- EDM-1213: Replace e2eregistry docker image with flightctl quay.io copy (sserafin)
- EDM-1208: fix e2e cli tests in ocp and adjust timeout (sserafin)
- EDM-1172: Add disconnected clusters support to e2e test vm (sserafin)
- NO-ISSUE: Use redis from quay.io (rawagner)
- EDM-683: Add API for listing distinct device labels (#939) (Assaf Albo)
- EDM-1202: Fix missing Flightctl API Server version in upstream images (asafbss)
- NO-ISSUE: wrong dependencies in spec (Gregory Shilin)
- EDM-1195: Ensure that release-* branches create containers (#954) (Miguel Angel Ajo Pelayo)
- EDM-1191: docs/managing-devices: add section on pull secrets (Sam Batschelet)
- EDM-1178: API client should refresh expired token (Ori Amizur)
- EDM-1191: agent: ensure OS image pull uses ostree path (Sam Batschelet)
- EDM-1181: Update nameOrAlias selector in E2E test (amalykhi)
- NO-ISSUE: copying example yamls to test directory for testing purpose (amalykhi)
- EDM-1076: Improve docs for installing fctl on disconnected env (rawagner)
- EDM-1034: agent/hooks: add support for passing variables to hooks from inline cfg (Sam Batschelet)
- EDM-960: Validations of inline config (amalykhi)
- EDM-1181: ensure camelCase consistency in selector names (#936) (Assaf Albo)
- EDM-1048: api/validation: always validate image (Sam Batschelet)
- EDM-1047: api/validation: ensure whitespace is not valid for application name (Sam Batschelet)
- EDM-1049: CLI installed from RPM (COPR repo) and binary (GH) show the wrong version info (#925) (Gregory Shilin)
- NO-ISSUE: Update docs to refer to stable COPR repo (Frank A. Zdarsky)
- NO-ISSUE: Ensure that tags are treated as strings (rawagner)
- EDM-1176: Do not use images with floating tags (rawagner)
- EDM-1045: Adding E2E tests for finalizing parametrisable device templates (sserafin)
- EDM-1174: Use Authorization header instead of Authentication to align with HTTP spec (#918) (Rastislav Wagner)
- EDM-1168: Make --rendered flag return the full device (Frank A. Zdarsky)
- EDM-1160: docs: update stale references (Sam Batschelet)
- EDM-1160: api/vaidation: ensure consoles can not be added directly to device (Sam Batschelet)
- EDM-1160: *: react to api changes (Sam Batschelet)
- EDM-1160: api: add versioning to agent (Sam Batschelet)
- NO-ISSUE: Remove tar before re-creating it (#903) (Gregory Shilin)
- EDM-1112: pods pull from quay.io in disconnected env (#904) (Gregory Shilin)
- NO-ISSUE: Add API group to docs yamls (Avishay Traeger)
- NO-ISSUE: keep agent config naming consistent in getting started guide (Nick Cao)
- NO-ISSUE: Various user doc fixes (Frank A. Zdarsky)
- Update getting-started.md with Hyperlinks (Florian Moss)

* Thu May 1 2025 Lily Sturmann <lkatalin@users.noreply.github.com> - 0.6.0~main~196~g84140b04-1.20250501151546365593.tpm.client.may.1.196.g84140b04
- d (Lily Sturmann)
- c (Lily Sturmann)
- b (Lily Sturmann)
- a (Lily Sturmann)
- fooO (Lily Sturmann)
- fooo (Lily Sturmann)
- foo (Lily Sturmann)
- bug fix wip 2 (Lily Sturmann)
- bug fix wip (Lily Sturmann)
- fake commit for systemd change (Lily Sturmann)
- EDM-1016: Add experimental feature to register TPM collection functions (Lily Sturmann)
- EDM-1016: Add TPM client agent-side (Lily Sturmann)
- EDM-1016: Fix for TPM system path (Lily Sturmann)
- EDM-1016: Include collector function data in system info (Lily Sturmann)
- NO-ISSUE: Remove --previous from kubectl log collection (Avishay Traeger)
- EDM-1315: Add events to create/update/delete APIs (Avishay Traeger)
- EDM-1275: Event retention (Avishay Traeger)
- EDM-1276: Add event listing to CLI (Avishay Traeger)
- NO-ISSUE: Fix selector resolving (Avishay Traeger)
- EDM-1274: Store system events in the database (Avishay Traeger)
- EDM-1276: Implement API to retrieve events (Avishay Traeger)
- EDM-1337: Modify nginx config to use only tls 1.3 (Dakota Crowder)
- EDM-1337: Change Warning err messages to Error (Dakota Crowder)
- EDM-1337: Modify rpm spec for install (Dakota Crowder)
- EDM-1337: Adjust setup to use default user for cli container (Dakota Crowder)
- EDM-1337: Install a flightctl-cli-artifacts quadlet (Dakota Crowder)
- EDM-1061: Add function to get TPM vendor info (Lily Sturmann)
- EDM-1435: agent/systemInfo: refactor and implement api (Sam Batschelet)
- EDM-1436: api: extend systemInfo status (Sam Batschelet)
- EDM-837: Document builds with RHEL base image (Frank A. Zdarsky)
- NO-ISSUE: Wrong code is generated for python (Gregory Shilin)
- EDM-1016: Add TPM functionality and unit tests to support attestation (Lily Sturmann)
- NO-ISSUE: Fixing Lint (Siddarth R)
- NO-ISSUE: Add ARM support for CPUInfo (Siddarth R)
- EDM-1333: refactoring to tests (Eldar Weiss)
- EDM-1453: agent: improve transient error handling (Sam Batschelet)
- EDM-1428: Add reload support for configuration changes (Ori Amizur)
- EDM-1452: Fix reference to ensure websocket handler is configured with middleware (Dakota Crowder)
- JIRA-1450:Incorrect Endpoint Used for CSR Approval (Siddarth Royapally)
- EDM-1429: agent: react to changes (Sam Batschelet)
- EDM-1429: agent: add systeminfo manager (Sam Batschelet)
- EDM-1429: agent: add system-info subcommand (Sam Batschelet)
- NO-ISSUE: Use printf rather than echo -e (Dakota Crowder)
- NO-ISSUE: Fix newline run-on issue with no bootc agent container (Dakota Crowder)
- Revert "EDM-1374: Resource monitorType casing mismatch causes alert not being displayed" (Sam Batschelet)
- EDM-1184: changed SELinux policy to allow systemd to start the service (Mario Parra)
- EDM-1367: Create aap oauth app from auth token (Dakota Crowder)
- NO-ISSUE: gRPC streams connections are disconnected after 5 minutes (Ori Amizur)
- EDM-1414: Add patch support for DeviceStatus (Sam Batschelet)
- NO-ISSUE: Revert removal o tags by https://github.com/flightctl/flightctl/pull/1013/ (#1088) (Gregory Shilin)
- EDM-1413: Break out get_services_for_tag function (Dakota Crowder)
- EDM-1413: Address image ref diff for ui images in dev builds (Dakota Crowder)
- EDM-1413: Add comment for ~ replacement context (Dakota Crowder)
- EDM-1413: Set image tag for installed quadlets based off of rpm version (Dakota Crowder)
- EDM-1314: docs: add inline compose details (Sam Batschelet)
- EDM-1295: Configuration for cli artifacts in UI standalone deployment (Celia Amador)
- EDM-1370: Add comment to .target explaining what the Requires and After diretives mean wrt startup ordering (Dakota Crowder)
- EDM-1288: Create sos report plugin for flightctl (Ori Amizur)
- EDM-1370: Remove redundant Wants from target (Dakota Crowder)
- EDM-1370: Run daemon-reload in post install (Dakota Crowder)
- EDM-1370: Improve service dependency mappings and use a .target instead of slice (Dakota Crowder)
- EDM-1333: adding coverage for more steps (Eldar Weiss)
- EDM-1374: Resource monitorType casing mismatch causes alert not being displayed (Sam Batschelet)
- NO-ISSUE: agent/os: only pull if not booted (Sam Batschelet)
- NO-ISSUE: Cleanup remnants from grpc endpoint previously surfaced at 7444 (Dakota Crowder)
- EDM-1186: Updates to quadlets config and rpm spec per feedback (Dakota Crowder)
- EDM-1186: RPM Quadlet Installer initial implementation (Dakota Crowder)
- EDM-1186: Use podman secrets to manage db and kv passwords (Dakota Crowder)
- EDM-1394: Revert "EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update" (#1080) (Assaf Albo)
- NO-ISSUE: Fixed minor issues with helm chart when using gateway API (Ram)
- NO-ISSUE: fix for login validation (amalykhi)
- NO-ISSUE: flightctl login validation test (amalykhi)
- EDM-1305:  Console enhancements (Ori Amizur)
- EDM-1313: agent: ensure update error condition is visible (Sam Batschelet)
- EDM-996: flightctl-agent rpm should create /etc/flightctl/ directory (#1069) (Gregory Shilin)
- EDM-1318: Bug fix removing client cert creation at startup (noga-magen)
- EDM-1320: api: improve compose spec validations (Sam Batschelet)
- NO-ISSUE: agent: improve initial sync timing (Sam Batschelet)
- EDM-889: Separate out auth provider config (Frank A. Zdarsky)
- EDM-889: Revert change in token serialization (Frank A. Zdarsky)
- EDM-889: Omit empty fields (Frank A. Zdarsky)
- NO-ISSUE: Added Note (Siddarth R)
- NO-ISSUE: Define global pull policy and use IfNotPresent (rawagner)
- EDM-1320: applications: improve provider validation (Sam Batschelet)
- EDM-1049: Use Stringer to format version (Frank A. Zdarsky)
- EDM-1049: Show field names when printing JSON and YAML output (Frank A. Zdarsky)
- EDM-1049: Enable use of context global flag (Frank A. Zdarsky)
- EDM-1354: In OCP flightctl-cli-artifacts pod is in CrashLoopBackOff installing with the latest helm chart (rawagner)
- EDM-1352: Building a gitserver as a root user fails (#1058) (Gregory Shilin)
- EDM-1294: Expose CLI Downloads via route and gateway. Create ConsoleCLIDownloads CR. (rawagner)
- EDM-1293: Deploy a pod with CLI tools (#1036) (Gregory Shilin)
- EDM-1329: agent/resource: calculate CPU usage with delta-based sampling (Sam Batschelet)
- EDM-1254: Add user documentation for rollout policies (Ori Amizur)
- EDM-1346: bump x/oauth2 and x/crypto (rawagner)
- EDM-1165: Fix AuthZ middleware. Add tests (rawagner)
- EDM-851: Update DevicesSummary to prevent null return (Siddarth R)
- Revert "EDM 851: Update DevicesSummary OpenAPI spec" (Siddarth R)
- EDM-1317: EDM-1321: api: add missing inline application eval (Sam Batschelet)
- EDM-310: Refactor CA handling (Anton Ivanov)
- NO-ISSUE: Update helm charts with new UI params (rawagner)
- EDM 851: Update DevicesSummary OpenAPI spec (Siddarth R)
- NO-ISSUE: Fix status e2e test (sserafin)
- NO-ISSUE: Anchors are not currently supported for workflows (#1013) (Gregory Shilin)
- EDM-1308: Use chi middleware request IDs (Avishay Traeger)
- EDM-1211: *: implement inline application provider (Sam Batschelet)
- EDM-1211: agent/applications: refactor (Sam Batschelet)
- EDM-1211: api: add application inline provider (Sam Batschelet)
- EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update (#1011) (Assaf Albo)
- EDM-1309: Prevent client from setting ER status (Avishay Traeger)
- EDM-1252:Adding labels (Eldar101)
- EDM-696: Support AAP Gateway OAuth2 (rawagner)
- NO-ISSUE: Make example enrollment request valid (Celia Amador)
- EDM-1214: Perform better validation of CSR and enrollment requests (Anton Ivanov)
- EDM-1251: fix JSONB fields in CompositeSelectorResolver (#995) (Assaf Albo)
- EDM-1138: Upgrade go to RH-supported (and FIPS-compatible) version (#980) (Gregory Shilin)
- EDM-1039: Make CLI code Windows compatible (#951) (Gregory Shilin)
- EDM-1044: Add part 1 of hooks e2e tests and small disconnected adaptations (sserafin)
- NO-ISSUE: fix ppa-build (#985) (Gregory Shilin)
- NO-ISSUE: Update CLI login docs (rawagner)
- EDM-1025: Use ServiceHandler rather than Store in tasks (Avishay Traeger)
- EDM-759: Add provisioning, update image building (Frank A. Zdarsky)
- EDM-1245: Add versioning to Device Simulator (#984) (Gregory Shilin)
- NO-ISSUE: Ensure Git metadata persists correctly in Flightctl API build (#970) (Assaf Albo)
- EDM-1247: Use plural selectors for labels endpoint (#979) (Assaf Albo)
- EDM-1049: Add a global RequestTimeout flag to use in CLI commands (#924) (Gregory Shilin)
- EDM-1241: In disconnected env the token fails to be refreshed (Ori Amizur)
- NO-ISSUE: Add docs for decommissioning (Lily Sturmann)
- NO-ISSUE: Remove escapes, remove experimental (Frank A. Zdarsky)
- EDM-1192: Split transport and service layers (Avishay Traeger)
- EDM-1209: Fix token verification error for OR selectors (#966) (Assaf Albo)
- NO-ISSUE: Fix to disconnected-cluster.md (Eldar101)
- EDM-1213: Use alpine from quay.io (sserafin)
- EDM-1213: Replace e2eregistry docker image with flightctl quay.io copy (sserafin)
- EDM-1208: fix e2e cli tests in ocp and adjust timeout (sserafin)
- EDM-1172: Add disconnected clusters support to e2e test vm (sserafin)
- NO-ISSUE: Use redis from quay.io (rawagner)
- EDM-683: Add API for listing distinct device labels (#939) (Assaf Albo)
- EDM-1202: Fix missing Flightctl API Server version in upstream images (asafbss)
- NO-ISSUE: wrong dependencies in spec (Gregory Shilin)
- EDM-1195: Ensure that release-* branches create containers (#954) (Miguel Angel Ajo Pelayo)
- EDM-1191: docs/managing-devices: add section on pull secrets (Sam Batschelet)
- EDM-1178: API client should refresh expired token (Ori Amizur)
- EDM-1191: agent: ensure OS image pull uses ostree path (Sam Batschelet)
- EDM-1181: Update nameOrAlias selector in E2E test (amalykhi)
- NO-ISSUE: copying example yamls to test directory for testing purpose (amalykhi)
- EDM-1076: Improve docs for installing fctl on disconnected env (rawagner)
- EDM-1034: agent/hooks: add support for passing variables to hooks from inline cfg (Sam Batschelet)
- EDM-960: Validations of inline config (amalykhi)
- EDM-1181: ensure camelCase consistency in selector names (#936) (Assaf Albo)
- EDM-1048: api/validation: always validate image (Sam Batschelet)
- EDM-1047: api/validation: ensure whitespace is not valid for application name (Sam Batschelet)
- EDM-1049: CLI installed from RPM (COPR repo) and binary (GH) show the wrong version info (#925) (Gregory Shilin)
- NO-ISSUE: Update docs to refer to stable COPR repo (Frank A. Zdarsky)
- NO-ISSUE: Ensure that tags are treated as strings (rawagner)
- EDM-1176: Do not use images with floating tags (rawagner)
- EDM-1045: Adding E2E tests for finalizing parametrisable device templates (sserafin)
- EDM-1174: Use Authorization header instead of Authentication to align with HTTP spec (#918) (Rastislav Wagner)
- EDM-1168: Make --rendered flag return the full device (Frank A. Zdarsky)
- EDM-1160: docs: update stale references (Sam Batschelet)
- EDM-1160: api/vaidation: ensure consoles can not be added directly to device (Sam Batschelet)
- EDM-1160: *: react to api changes (Sam Batschelet)
- EDM-1160: api: add versioning to agent (Sam Batschelet)
- NO-ISSUE: Remove tar before re-creating it (#903) (Gregory Shilin)
- EDM-1112: pods pull from quay.io in disconnected env (#904) (Gregory Shilin)
- NO-ISSUE: Add API group to docs yamls (Avishay Traeger)
- NO-ISSUE: keep agent config naming consistent in getting started guide (Nick Cao)
- NO-ISSUE: Various user doc fixes (Frank A. Zdarsky)
- Update getting-started.md with Hyperlinks (Florian Moss)

* Thu May 1 2025 Lily Sturmann <lkatalin@users.noreply.github.com> - 0.6.0~main~191~g268f28e0-1.20250501144712814167.tpm.client.may.1.191.g268f28e0
- fooo (Lily Sturmann)
- foo (Lily Sturmann)
- bug fix wip 2 (Lily Sturmann)
- bug fix wip (Lily Sturmann)
- fake commit for systemd change (Lily Sturmann)
- EDM-1016: Add experimental feature to register TPM collection functions (Lily Sturmann)
- EDM-1016: Add TPM client agent-side (Lily Sturmann)
- EDM-1016: Fix for TPM system path (Lily Sturmann)
- EDM-1016: Include collector function data in system info (Lily Sturmann)
- NO-ISSUE: Remove --previous from kubectl log collection (Avishay Traeger)
- EDM-1315: Add events to create/update/delete APIs (Avishay Traeger)
- EDM-1275: Event retention (Avishay Traeger)
- EDM-1276: Add event listing to CLI (Avishay Traeger)
- NO-ISSUE: Fix selector resolving (Avishay Traeger)
- EDM-1274: Store system events in the database (Avishay Traeger)
- EDM-1276: Implement API to retrieve events (Avishay Traeger)
- EDM-1337: Modify nginx config to use only tls 1.3 (Dakota Crowder)
- EDM-1337: Change Warning err messages to Error (Dakota Crowder)
- EDM-1337: Modify rpm spec for install (Dakota Crowder)
- EDM-1337: Adjust setup to use default user for cli container (Dakota Crowder)
- EDM-1337: Install a flightctl-cli-artifacts quadlet (Dakota Crowder)
- EDM-1061: Add function to get TPM vendor info (Lily Sturmann)
- EDM-1435: agent/systemInfo: refactor and implement api (Sam Batschelet)
- EDM-1436: api: extend systemInfo status (Sam Batschelet)
- EDM-837: Document builds with RHEL base image (Frank A. Zdarsky)
- NO-ISSUE: Wrong code is generated for python (Gregory Shilin)
- EDM-1016: Add TPM functionality and unit tests to support attestation (Lily Sturmann)
- NO-ISSUE: Fixing Lint (Siddarth R)
- NO-ISSUE: Add ARM support for CPUInfo (Siddarth R)
- EDM-1333: refactoring to tests (Eldar Weiss)
- EDM-1453: agent: improve transient error handling (Sam Batschelet)
- EDM-1428: Add reload support for configuration changes (Ori Amizur)
- EDM-1452: Fix reference to ensure websocket handler is configured with middleware (Dakota Crowder)
- JIRA-1450:Incorrect Endpoint Used for CSR Approval (Siddarth Royapally)
- EDM-1429: agent: react to changes (Sam Batschelet)
- EDM-1429: agent: add systeminfo manager (Sam Batschelet)
- EDM-1429: agent: add system-info subcommand (Sam Batschelet)
- NO-ISSUE: Use printf rather than echo -e (Dakota Crowder)
- NO-ISSUE: Fix newline run-on issue with no bootc agent container (Dakota Crowder)
- Revert "EDM-1374: Resource monitorType casing mismatch causes alert not being displayed" (Sam Batschelet)
- EDM-1184: changed SELinux policy to allow systemd to start the service (Mario Parra)
- EDM-1367: Create aap oauth app from auth token (Dakota Crowder)
- NO-ISSUE: gRPC streams connections are disconnected after 5 minutes (Ori Amizur)
- EDM-1414: Add patch support for DeviceStatus (Sam Batschelet)
- NO-ISSUE: Revert removal o tags by https://github.com/flightctl/flightctl/pull/1013/ (#1088) (Gregory Shilin)
- EDM-1413: Break out get_services_for_tag function (Dakota Crowder)
- EDM-1413: Address image ref diff for ui images in dev builds (Dakota Crowder)
- EDM-1413: Add comment for ~ replacement context (Dakota Crowder)
- EDM-1413: Set image tag for installed quadlets based off of rpm version (Dakota Crowder)
- EDM-1314: docs: add inline compose details (Sam Batschelet)
- EDM-1295: Configuration for cli artifacts in UI standalone deployment (Celia Amador)
- EDM-1370: Add comment to .target explaining what the Requires and After diretives mean wrt startup ordering (Dakota Crowder)
- EDM-1288: Create sos report plugin for flightctl (Ori Amizur)
- EDM-1370: Remove redundant Wants from target (Dakota Crowder)
- EDM-1370: Run daemon-reload in post install (Dakota Crowder)
- EDM-1370: Improve service dependency mappings and use a .target instead of slice (Dakota Crowder)
- EDM-1333: adding coverage for more steps (Eldar Weiss)
- EDM-1374: Resource monitorType casing mismatch causes alert not being displayed (Sam Batschelet)
- NO-ISSUE: agent/os: only pull if not booted (Sam Batschelet)
- NO-ISSUE: Cleanup remnants from grpc endpoint previously surfaced at 7444 (Dakota Crowder)
- EDM-1186: Updates to quadlets config and rpm spec per feedback (Dakota Crowder)
- EDM-1186: RPM Quadlet Installer initial implementation (Dakota Crowder)
- EDM-1186: Use podman secrets to manage db and kv passwords (Dakota Crowder)
- EDM-1394: Revert "EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update" (#1080) (Assaf Albo)
- NO-ISSUE: Fixed minor issues with helm chart when using gateway API (Ram)
- NO-ISSUE: fix for login validation (amalykhi)
- NO-ISSUE: flightctl login validation test (amalykhi)
- EDM-1305:  Console enhancements (Ori Amizur)
- EDM-1313: agent: ensure update error condition is visible (Sam Batschelet)
- EDM-996: flightctl-agent rpm should create /etc/flightctl/ directory (#1069) (Gregory Shilin)
- EDM-1318: Bug fix removing client cert creation at startup (noga-magen)
- EDM-1320: api: improve compose spec validations (Sam Batschelet)
- NO-ISSUE: agent: improve initial sync timing (Sam Batschelet)
- EDM-889: Separate out auth provider config (Frank A. Zdarsky)
- EDM-889: Revert change in token serialization (Frank A. Zdarsky)
- EDM-889: Omit empty fields (Frank A. Zdarsky)
- NO-ISSUE: Added Note (Siddarth R)
- NO-ISSUE: Define global pull policy and use IfNotPresent (rawagner)
- EDM-1320: applications: improve provider validation (Sam Batschelet)
- EDM-1049: Use Stringer to format version (Frank A. Zdarsky)
- EDM-1049: Show field names when printing JSON and YAML output (Frank A. Zdarsky)
- EDM-1049: Enable use of context global flag (Frank A. Zdarsky)
- EDM-1354: In OCP flightctl-cli-artifacts pod is in CrashLoopBackOff installing with the latest helm chart (rawagner)
- EDM-1352: Building a gitserver as a root user fails (#1058) (Gregory Shilin)
- EDM-1294: Expose CLI Downloads via route and gateway. Create ConsoleCLIDownloads CR. (rawagner)
- EDM-1293: Deploy a pod with CLI tools (#1036) (Gregory Shilin)
- EDM-1329: agent/resource: calculate CPU usage with delta-based sampling (Sam Batschelet)
- EDM-1254: Add user documentation for rollout policies (Ori Amizur)
- EDM-1346: bump x/oauth2 and x/crypto (rawagner)
- EDM-1165: Fix AuthZ middleware. Add tests (rawagner)
- EDM-851: Update DevicesSummary to prevent null return (Siddarth R)
- Revert "EDM 851: Update DevicesSummary OpenAPI spec" (Siddarth R)
- EDM-1317: EDM-1321: api: add missing inline application eval (Sam Batschelet)
- EDM-310: Refactor CA handling (Anton Ivanov)
- NO-ISSUE: Update helm charts with new UI params (rawagner)
- EDM 851: Update DevicesSummary OpenAPI spec (Siddarth R)
- NO-ISSUE: Fix status e2e test (sserafin)
- NO-ISSUE: Anchors are not currently supported for workflows (#1013) (Gregory Shilin)
- EDM-1308: Use chi middleware request IDs (Avishay Traeger)
- EDM-1211: *: implement inline application provider (Sam Batschelet)
- EDM-1211: agent/applications: refactor (Sam Batschelet)
- EDM-1211: api: add application inline provider (Sam Batschelet)
- EDM-1290: Allow passing nil maps to distinguish between missing and empty labels during resource update (#1011) (Assaf Albo)
- EDM-1309: Prevent client from setting ER status (Avishay Traeger)
- EDM-1252:Adding labels (Eldar101)
- EDM-696: Support AAP Gateway OAuth2 (rawagner)
- NO-ISSUE: Make example enrollment request valid (Celia Amador)
- EDM-1214: Perform better validation of CSR and enrollment requests (Anton Ivanov)
- EDM-1251: fix JSONB fields in CompositeSelectorResolver (#995) (Assaf Albo)
- EDM-1138: Upgrade go to RH-supported (and FIPS-compatible) version (#980) (Gregory Shilin)
- EDM-1039: Make CLI code Windows compatible (#951) (Gregory Shilin)
- EDM-1044: Add part 1 of hooks e2e tests and small disconnected adaptations (sserafin)
- NO-ISSUE: fix ppa-build (#985) (Gregory Shilin)
- NO-ISSUE: Update CLI login docs (rawagner)
- EDM-1025: Use ServiceHandler rather than Store in tasks (Avishay Traeger)
- EDM-759: Add provisioning, update image building (Frank A. Zdarsky)
- EDM-1245: Add versioning to Device Simulator (#984) (Gregory Shilin)
- NO-ISSUE: Ensure Git metadata persists correctly in Flightctl API build (#970) (Assaf Albo)
- EDM-1247: Use plural selectors for labels endpoint (#979) (Assaf Albo)
- EDM-1049: Add a global RequestTimeout flag to use in CLI commands (#924) (Gregory Shilin)
- EDM-1241: In disconnected env the token fails to be refreshed (Ori Amizur)
- NO-ISSUE: Add docs for decommissioning (Lily Sturmann)
- NO-ISSUE: Remove escapes, remove experimental (Frank A. Zdarsky)
- EDM-1192: Split transport and service layers (Avishay Traeger)
- EDM-1209: Fix token verification error for OR selectors (#966) (Assaf Albo)
- NO-ISSUE: Fix to disconnected-cluster.md (Eldar101)
- EDM-1213: Use alpine from quay.io (sserafin)
- EDM-1213: Replace e2eregistry docker image with flightctl quay.io copy (sserafin)
- EDM-1208: fix e2e cli tests in ocp and adjust timeout (sserafin)
- EDM-1172: Add disconnected clusters support to e2e test vm (sserafin)
- NO-ISSUE: Use redis from quay.io (rawagner)
- EDM-683: Add API for listing distinct device labels (#939) (Assaf Albo)
- EDM-1202: Fix missing Flightctl API Server version in upstream images (asafbss)
- NO-ISSUE: wrong dependencies in spec (Gregory Shilin)
- EDM-1195: Ensure that release-* branches create containers (#954) (Miguel Angel Ajo Pelayo)
- EDM-1191: docs/managing-devices: add section on pull secrets (Sam Batschelet)
- EDM-1178: API client should refresh expired token (Ori Amizur)
- EDM-1191: agent: ensure OS image pull uses ostree path (Sam Batschelet)
- EDM-1181: Update nameOrAlias selector in E2E test (amalykhi)
- NO-ISSUE: copying example yamls to test directory for testing purpose (amalykhi)
- EDM-1076: Improve docs for installing fctl on disconnected env (rawagner)
- EDM-1034: agent/hooks: add support for passing variables to hooks from inline cfg (Sam Batschelet)
- EDM-960: Validations of inline config (amalykhi)
- EDM-1181: ensure camelCase consistency in selector names (#936) (Assaf Albo)
- EDM-1048: api/validation: always validate image (Sam Batschelet)
- EDM-1047: api/validation: ensure whitespace is not valid for application name (Sam Batschelet)
- EDM-1049: CLI installed from RPM (COPR repo) and binary (GH) show the wrong version info (#925) (Gregory Shilin)
- NO-ISSUE: Update docs to refer to stable COPR repo (Frank A. Zdarsky)
- NO-ISSUE: Ensure that tags are treated as strings (rawagner)
- EDM-1176: Do not use images with floating tags (rawagner)
- EDM-1045: Adding E2E tests for finalizing parametrisable device templates (sserafin)
- EDM-1174: Use Authorization header instead of Authentication to align with HTTP spec (#918) (Rastislav Wagner)
- EDM-1168: Make --rendered flag return the full device (Frank A. Zdarsky)
- EDM-1160: docs: update stale references (Sam Batschelet)
- EDM-1160: api/vaidation: ensure consoles can not be added directly to device (Sam Batschelet)
- EDM-1160: *: react to api changes (Sam Batschelet)
- EDM-1160: api: add versioning to agent (Sam Batschelet)
- NO-ISSUE: Remove tar before re-creating it (#903) (Gregory Shilin)
- EDM-1112: pods pull from quay.io in disconnected env (#904) (Gregory Shilin)
- NO-ISSUE: Add API group to docs yamls (Avishay Traeger)
- NO-ISSUE: keep agent config naming consistent in getting started guide (Nick Cao)
- NO-ISSUE: Various user doc fixes (Frank A. Zdarsky)
- Update getting-started.md with Hyperlinks (Florian Moss)

* Tue Apr 15 2025 Dakota Crowder <dcrowder@redhat.com> - 0.6.0-4
- Add ability to create an AAP Oauth Application within flightctl-services sub-package
* Fri Apr 11 2025 Dakota Crowder <dcrowder@redhat.com> - 0.6.0-3
- Add versioning to container images within flightctl-services sub-package
* Thu Apr 3 2025 Ori Amizur <oamizur@redhat.com> - 0.6.0-2
- Add sos report plugin support
* Mon Mar 31 2025 Dakota Crowder <dcrowder@redhat.com> - 0.6.0-1
- Add services sub-package for installation of containerized flightctl services
* Fri Feb 7 2025 Miguel Angel Ajo <majopela@redhat.com> - 0.4.0-1
- Add selinux support for console pty access
* Mon Nov 4 2024 Miguel Angel Ajo <majopela@redhat.com> - 0.3.0-1
- Move the Release field to -1 so we avoid auto generating packages
  with -5 all the time.
* Wed Aug 21 2024 Sam Batschelet <sbatsche@redhat.com> - 0.0.1-5
- Add must-gather script to provide a simple mechanism to collect agent debug
* Wed Aug 7 2024 Sam Batschelet <sbatsche@redhat.com> - 0.0.1-4
- Add basic greenboot support for failed flightctl-agent service
* Wed Mar 13 2024 Ricardo Noriega <rnoriega@redhat.com> - 0.0.1-3
- New specfile for both CLI and agent packages
